@@ -48,8 +48,7 @@ $dtc_database = array(
 			"ob_next" => "varchar(64) NOT NULL default ''",
 			"last_used_lang" => "varchar(32) NOT NULL default 'en_US.UTF-8'",
 			"recovery_token" => "varchar(64) NOT NULL default ''",
-			"recovery_timestamp" => "int(12) NOT NULL default '0'",
-			"max_ssh" => "int(12) NOT NULL default '3'"
+			"recovery_timestamp" => "int(12) NOT NULL default '0'"
 		),
 		"primary" => "(adm_login)",
 		"index" => array(
@@ -218,6 +217,12 @@ $dtc_database = array(
 			"ftp_backup_activate" => "enum('yes','no') NOT NULL default 'no'",
 			"ftp_backup_dest_folder" => "varchar(255) NOT NULL default '/'",
 			"ftp_active_mode" => "enum('yes','no') NOT NULL default 'no'",
+			"ftp_ssh_mode" => "enum('yes','no') NOT NULL default 'no'",
+			"ftp_backup_host_ssh" => "varchar(255) NOT NULL default ''",
+			"ftp_backup_dest_folder_ssh" => "varchar(255) NOT NULL default '/'",
+			"ftp_ftp_mode" => "enum('yes','no') NOT NULL default 'no'",
+			"ftp_7z_mode" => "enum('yes','no') NOT NULL default 'no'",
+			"ftp_7z_level" => "enum('fastest','fast','normal','max','ultra') NOT NULL default 'normal'",
 			"vps_renewal_before" => "varchar(64) NOT NULL default '5|10'",
 			"vps_renewal_after" => "varchar(64) NOT NULL default '3|7'",
 			"vps_renewal_lastwarning" => "varchar(64) NOT NULL default '12'",
@@ -247,6 +252,7 @@ $dtc_database = array(
 			"default_company_invoicing" => "int(12) NOT NULL default '0'",
 			"this_server_country_code" => "varchar(4) NOT NULL default 'US'",
 			"use_cyrus" => "enum('yes','no') NOT NULL default 'no'",
+			"use_sieve" => "enum('yes','no') NOT NULL default 'no'",
 			"use_amavis" => "enum('yes','no') NOT NULL default 'yes'",
 			"use_clamav" => "enum('yes','no') NOT NULL default 'yes'",
 			"use_advanced_lists_tunables" => "enum('yes','no') NOT NULL default 'no'",
@@ -292,7 +298,10 @@ $dtc_database = array(
 			"this_server_default_tld" => "varchar(10) NOT NULL default '.com'",
 			"panel_logolink" => "varchar(255) NOT NULL default 'default'",
 			"invoice_scp_addr" => "varchar(255) NOT NULL default ''",
-			"invoice_scp_when" => "enum('day','month') NOT NULL default 'day'"
+			"invoice_scp_when" => "enum('day','month') NOT NULL default 'day'",
+			"autogen_webmail_protocol" => "enum('http:','https:') NOT NULL default 'https:'",
+			"post_or_get" => "enum('GET','POST') NOT NULL default 'POST'",
+			"send_cron_alert" => "enum('yes','no') NOT NULL default 'no'"
 		),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -341,7 +350,13 @@ $dtc_database = array(
 		"vars" => array(
 			"id" => "int(11) NOT NULL auto_increment",
 			"name" => "varchar(32) NOT NULL default ''",
-			"reqdomain" => "enum('yes','no') NOT NULL default 'no'"
+			"reqdomain" => "enum('yes','no') NOT NULL default 'no'",
+			"new_account_execution_type" => "enum('none','url','eval','admin_email') NOT NULL default 'none'",
+			"new_account_command" => "text",
+			"expiration_execution_type" => "enum('none','url','eval','admin_email') NOT NULL default 'none'",
+			"expiration_command" => "text",
+			"renewall_execution_type" => "enum('none','url','eval','admin_email') NOT NULL default 'none'",
+			"renewall_command" => "text"
 		),
 		"primary" => "(id)",
 		"keys" => array(
@@ -748,7 +763,8 @@ $dtc_database = array(
 			"maxmind_output" => "text",
 			"last_used_lang" => "varchar(32) NOT NULL default 'en_US.UTF-8'",
 			"add_service" => "enum('yes','no') NOT NULL default 'no'",
-			"customfld" => "text"
+			"customfld" => "text",
+			"archive" => "enum('yes','no') NOT NULL default 'no'"
 		),
 		"primary" => "(id)"
 	),
@@ -1044,6 +1060,7 @@ $dtc_database = array(
 			"unicrow" => "int(2) NOT NULL default '0'",
 			"currency_symbol" => "varchar(16) NOT NULL default '$'",
 			"currency_letters" => "varchar(16) NOT NULL default 'USD'",
+			"use_products_for_renewal" => "enum('yes','no') NOT NULL default 'no'",
 			"use_paypal" => "enum('yes','no') NOT NULL default 'no'",
 			"paypal_rate" => "float(6,2) NOT NULL default '0.00'",
 			"paypal_flat" => "float(6,2) NOT NULL default '0.00'",
@@ -1329,6 +1346,16 @@ $dtc_database = array(
 			"pseudo" => "(pseudo)"
 		)
 	),
+	"tik_attach" => array(
+		"vars" => array(
+			"id" => "int(12) NOT NULL auto_increment",
+			"filename" => "varchar(255) NOT NULL default ''",
+			"ctype_prim" => "varchar(64) NOT NULL default ''",
+			"ctype_sec" => "varchar(64) NOT NULL default ''",
+			"datahex" => "mediumblob NOT NULL default ''"
+		),
+		"primary" => "(id)"
+	),
 	"tik_cats" => array(
 		"vars" => array(
 			"id" => "int(11) NOT NULL auto_increment",
@@ -1356,7 +1383,8 @@ $dtc_database = array(
 			"customer_email" => "varchar(255) NOT NULL default ''",
 			"closed" => "enum('yes','no') NOT NULL default 'no'",
 			"hash" => "varchar(32) NOT NULL default ''",
-			"admin_name" => "varchar(256) NOT NULL default 'dtc'"
+			"admin_name" => "varchar(256) NOT NULL default 'dtc'",
+			"attach" => "text"
 		),
 		"primary" => "(id)",
 		"index" => array(
@@ -1415,7 +1443,8 @@ $dtc_database = array(
 			"monitor_smtp" => "enum('yes','no') NOT NULL default 'no'",
 			"monitor_pop3" => "enum('yes','no') NOT NULL default 'no'",
 			"monitor_imap4" => "enum('yes','no') NOT NULL default 'no'",
-			"monitor_ftp" => "enum('yes','no') NOT NULL default 'no'"
+			"monitor_ftp" => "enum('yes','no') NOT NULL default 'no'",
+			"locked" => "enum('yes','no') NOT NULL default 'no'"
 		),
 		"primary" => "(id)",
 		"keys" => array(
@@ -1485,7 +1514,10 @@ $dtc_database = array(
 			"diskio_last" => "bigint(22) default NULL",
 			"diskio_count" => "bigint(22) default NULL",
 			"swapio_last" => "bigint(22) default NULL",
-			"swapio_count" => "bigint(22) default NULL"
+			"swapio_count" => "bigint(22) default NULL",
+			"tresh_before_warn_sent" => "enum('yes','no') NOT NULL default 'no'",
+			"tresh_quota_reached_warn_sent" => "enum('yes','no') NOT NULL default 'no'",
+			"tresh_vps_shutdown" => "enum('yes','no') NOT NULL default 'no'"
 		),
 		"primary" => "(month,year,vps_server_hostname,vps_xen_name)"
 	),
