@@ -433,6 +433,23 @@ function productManager(){
 		}else{
 			$type_id_replace[] = $ap["id"]. ": " .$ap["name"];
 		}
+	}
+	// Build the product ID popup
+		$qp = "SELECT id,name FROM $pro_mysql_product_table WHERE renew_prod_id='0' AND heb_type='custom' order by custom_heb_type";
+		$rp = mysql_query($qp)or die("Cannot query \"$qp\" !!! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$np = mysql_num_rows($rp);
+		$renew_id_popup = array();
+		$renew_id_popup[] = 0;
+		$renew_id_replace = array();
+		$renew_id_replace[] = _("Not a renewal product");
+	for($j=0;$j<$np;$j++){
+		$ap = mysql_fetch_array($rp);
+		$renew_id_popup[] = $ap["id"];
+		if(strlen($ap["name"]) > 20){
+			$renew_id_replace[] = $ap["id"]. ": " .substr($ap["name"],0,17)."...";
+		}else{
+			$renew_id_replace[] = $ap["id"]. ": " .$ap["name"];
+		}
 	}
 		$dsc = array(
 			"table_name" => $pro_mysql_product_table,
@@ -446,6 +463,13 @@ function productManager(){
 				"display" => "yes",
 				"legend" => "Id"
 				),
+			"renew_prod_id" => array(
+				"type" => "popup",
+				"help" => _("If you set the renewal ID, then this entry will be considered as a renewal product for the matching ID."),
+				"legend" => _("Renewal-ID") ,
+				"values" => $renew_id_popup,
+				"display_replace" => $renew_id_replace
+				),
 			"name" => array(
 				"type" => "text",
 				"legend" => _("Name") ,
@@ -514,14 +538,47 @@ function productManager(){
 				"legend" => "id"),
 			"name" => array(
 				"type" => "text",
-				"legend" => "name"),
+				"legend" => _("Name")),
 			"reqdomain" => array(
 				"type" => "checkbox",
 				"legend" => _("Requires Domain Name") ,
 				"help" => _("If the reqdomain flag is set, then this product will prompt for a domain name in the registration form."),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")),
-				"default" => "no")
+				"default" => "no"),
+			"new_account_execution_type" => array(
+				"type" => "popup",
+				"legend" => _("New account execution type") ,
+				"help" => _("Action to execute when a new account of this type is created. It can be none (no action is done), URL (a web url is opened in background), Ue PHP eval funtion (php code is executed with eval) or Send an email to admin (ends an email to the dtc administrator)"),
+				"values" => array('none','url','eval','admin_email'),
+				"display_replace" => array(_("None"),_("URL"),_("Use PHP eval function"),_("Send an email to admin")),
+				"default" => "none"),
+			"new_account_command" => array(
+				"type" => "textarea",
+				"help" => _("URL or command or mail body to execute or send when a new account of this type is created. To pass custom fields of the product to this, put them as %%%var%%% to be replaced by that custom field."),
+				"legend" => _("Command to execute when an account is created")),
+			"expiration_execution_type" => array(
+				"type" => "popup",
+				"legend" => _("Expiration execution type") ,
+				"help" => _("Action to execute when an account of this type expires. It can be none (no action is done), URL (a web url is opened in background), Ue PHP eval funtion (php code is executed with eval) or Send an email to admin (ends an email to the dtc administrator)"),
+				"values" => array('none','url','eval','admin_email'),
+				"display_replace" => array(_("None"),_("URL"),_("Use PHP eval function"),_("Send an email to admin")),
+				"default" => "none"),
+			"expiration_command" => array(
+				"type" => "textarea",
+				"help" => _("URL or command or mail body to execute or send when a custom product of this type expires. To pass custom fields of the product to this, put them as %%%var%%% to be replaced by that custom field."),
+				"legend" => _("Command to execute when an account expires")),
+			"renewall_execution_type" => array(
+				"type" => "popup",
+				"legend" => _("Renewall execution type") ,
+				"help" => _("Action to execute when a custom product of this type is renewed. It can be none (no action is done), URL (a web url is opened in background), Ue PHP eval funtion (php code is executed with eval) or Send an email to admin (ends an email to the dtc administrator)"),
+				"values" => array('none','url','eval','admin_email'),
+				"display_replace" => array(_("None"),_("URL"),_("Use PHP eval function"),_("Send an email to admin")),
+				"default" => "none"),
+			"renewall_command" => array(
+				"type" => "textarea",
+				"help" => _("URL or command or mail body to execute or send when a custom product of this type is renewed.  To pass custom fields of the product to this, put them as %%%var%%% to be replaced by that custom field."),
+				"legend" => _("Command to execute when an account is renewed")),
 			)
 		);
 	$out .= dtcDatagrid($dsc);
