@@ -201,6 +201,7 @@ function pro_vhost_generate(){
 
 	global $conf_autogen_webmail_alias;
 	global $conf_autogen_webmail_type;
+	global $conf_autogen_webmail_protocol;
 	
 	global $conf_use_shared_ssl;
 	$vhost_file = "";
@@ -402,11 +403,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 </Directory>\n";
 
 	if($conf_autogen_webmail_alias == "yes"){
-		if($conf_autogen_webmail_type == "squirrelmail"){
-			$vhost_file .= "RedirectPermanent /webmail https://$conf_administrative_site/squirrelmail\n";
-		}else{
-			$vhost_file .= "RedirectPermanent /webmail https://$conf_administrative_site/roundcube\n";
-		}
+		$vhost_file .= "RedirectPermanent /webmail $conf_autogen_webmail_protocol//$conf_administrative_site/$conf_autogen_webmail_type\n";
 	}
 
 	#############################
@@ -424,12 +421,11 @@ AND $pro_mysql_admin_table.id_client != '0'";
 		$a = mysql_fetch_array($r);
 		$vhost_file .= "
 <CBandUser ".$a["adm_login"].">
-	CBandSpeed 10Mbps 10 30
-	CBandRemoteSpeed 2Mbps 3 3
-	CBandLimit ".$a["bandwidth"]."M
-	CBandPeriod 4W
-	CBandPeriodSlice 1W
-	CBandExceededSpeed 32kbps 2 5
+	CBandUserSpeed 10Mbps 10 30
+	CBandUserLimit ".$a["bandwidth"]."M
+	CBandUserPeriod 4W
+	CBandUserPeriodSlice 1W
+	CBandUserExceededSpeed 32kbps 2 5
 	CBandUserScoreboard /var/lib/dtc/etc/cband_scores/".$a["adm_login"]."
 </CBandUser>
 ";
@@ -439,6 +435,38 @@ AND $pro_mysql_admin_table.id_client != '0'";
 	# end mod_cband user generation #
 	#################################
 
+	// autodiscover vhost
+	$autodiscover_hosts = array();
+	for ($i=0;$i<$num_rows;$i++) {
+		$row = mysql_fetch_array($result) or die ("Cannot fetch user");
+		$web_name = $row["name"];
+		if ($web_name == "" || $row['primary_mx'] != 'default' || $row['other_mx'] != 'default') {
+			continue;
+		}
+		$query2 = "SELECT COUNT(*) FROM $pro_mysql_subdomain_table WHERE domain_name='$web_name' AND subdomain_name='autodiscover';";
+		$result2 = mysql_query($query2) or die("Cannot execute query \"$query2\"");
+		if (mysql_result($result2, 0, 'COUNT(*)') > 0) {
+			continue;
+		}
+		$autodiscover_hosts[] = $web_name;
+	}			
+	mysql_data_seek($result, 0);
+	if (count($autodiscover_hosts) > 0) {
+		$vhost_file .= "<VirtualHost ".$conf_main_site_ip.":80>
+	ServerName autodiscover.$conf_main_domain\n";
+		foreach ($autodiscover_hosts as $autodiscover_host) {
+			$vhost_file .= "	ServerAlias autodiscover.$autodiscover_host\n";	
+		}
+		$vhost_file .="	Alias /autodiscover/autodiscover.xml $conf_generated_file_path/autodiscover-redirect.xml
+	<Location /autodiscover/autodiscover.xml>
+		Order Deny,Allow
+	</Location>
+	<LocationMatch \"^/(?!autodiscover/autodiscover.xml)\">
+		Order Allow,Deny
+	</LocationMatch>
+</VirtualHost>\n\n";
+	}
+	
 	for($i=0;$i<$num_rows;$i++){
 		$row = mysql_fetch_array($result) or die ("Cannot fetch user");
 		$web_name = $row["name"];
@@ -455,7 +483,8 @@ AND $pro_mysql_admin_table.id_client != '0'";
 		$domain_parking_type = $row["domain_parking_type"];
 		$domain_wildcard_dns = $row["wildcard_dns"];
 		$domain_default_sub_server_alias = $row["default_sub_server_alias"];
-
+		$create_mail_autoconfig = $row["primary_mx"] == "default";
+		
 		unset($backup_ip_addr);
 		if (isset($row["backup_ip_addr"])){
 			$backup_ip_addr = $row["backup_ip_addr"];
@@ -629,14 +658,20 @@ AND $pro_mysql_admin_table.id_client != '0'";
 						}else{
 							$gblx = "php_admin_value register_globals 0";
 						}
-						if($rowX["safe_mode"] == "no" && $ax["safe_mode"] == "no"){
-							$safex = "php_admin_value safe_mode 0";
+						if($php_vers_bigger_than_53 = 0){
+							if($rowX["safe_mode"] == "no" && $ax["safe_mode"] == "no"){
+								$safex = "php_admin_value safe_mode 0";
+							}else{
+								$safex = "php_admin_value safe_mode 1";
+							}
+							$my_open_basedir = "\n\t\tphp_admin_value open_basedir \"$web_pathX/$web_nameX/:$conf_php_library_path:$conf_php_additional_library_path:\"";
 						}else{
-							$safex = "php_admin_value safe_mode 1";
+							$my_open_basedir = "";
+							$safex = "";
 						}
 						$vhost_file .= "\tAlias /$subdomx.$web_nameX $web_pathX/$web_nameX/subdomains/$subdomx/html
 	<Location /$subdomx.$web_nameX>
-		".$safex.$custom_directives."
+		".$safex.$custom_directives.$my_open_basedir."
 		php_admin_value open_basedir \"$web_pathX/$web_nameX/:$conf_php_library_path:$conf_php_additional_library_path:\"
 		$gblx
 	</Location>\n";
@@ -670,6 +705,7 @@ AND $pro_mysql_admin_table.id_client != '0'";
 	Alias /squirrelmail ".$conf_tools_prefix."/squirrelmail
 	Alias /roundcube /var/lib/roundcube
 	Alias /extplorer /usr/share/extplorer
+	AliasMatch ^/autodiscover/autodiscover\.xml\$ $conf_generated_file_path/autodiscover.xml.php
 	php_admin_value sendmail_from webmaster@$web_name
 	DocumentRoot $web_path/$web_name/subdomains/$web_subname/html
 	<Directory $web_path/$web_name/subdomains/$web_subname/html>
@@ -907,13 +943,18 @@ $vhost_file .= "
 		Allow from all
 	</Directory>\n";
 							if($webadmin["shared_hosting_security"] == 'mod_php' && $shared_hosting_subdomain_security == 'mod_php'){
-								$vhost_file .= $vhost_more_conf.$php_more_conf."	php_admin_value safe_mode $safe_mode_value
+								if($php_vers_bigger_than_53){
+									$my_php_safe_mode = "";
+									$my_open_basedir = "";
+								}else{
+									$my_php_safe_mode = "\n\tphp_admin_value safe_mode $safe_mode_value";
+									$my_open_basedir = "\n\t<Location />
+		php_admin_value open_basedir \"$web_path:$conf_php_library_path:$conf_php_additional_library_path:\"\n\t</Location>";
+								}
+								$vhost_file .= $vhost_more_conf.$php_more_conf.$my_php_safe_mode."
 	php_admin_value sendmail_from phpmailfunction$web_subname@$web_name
 	php_admin_value sendmail_path \"/usr/sbin/sendmail -t -i -f phpmailfunction$web_subname@$domain_to_get\"
-	php_value session.save_path $web_path/$domain_to_get/subdomains/$web_subname/tmp
-	<Location />
-		php_admin_value open_basedir \"$web_path:$conf_php_library_path:$conf_php_additional_library_path:\"
-	</Location>
+	php_value session.save_path $web_path/$domain_to_get/subdomains/$web_subname/tmp".$my_open_basedir."
 	$cgi_directive\n";
 							}else{
 								$vhost_file .= "$vhost_more_conf	ScriptAlias /cgi-bin /usr/lib/cgi-bin
@@ -946,10 +987,14 @@ $vhost_file .= "
 	</IfModule>
 	<IfModule mod_cband.c>
 		CBandUser $web_owner
-	</IfModule>
-</VirtualHost>
+		CBandRemoteSpeed 2Mbps 3 3
+	</IfModule>\n";
 
-";
+						if ($create_mail_autoconfig && ($domain_default_sub_server_alias == "yes") && ($web_subname == "$web_default_subdomain")) {
+							$vhost_file .= "	AliasMatch ^/.well-known/autoconfig/mail/config-v1.1.xml\$ $conf_generated_file_path/config-v1.1.xml\n";
+						}
+	
+						$vhost_file .= "</VirtualHost>\n\n";
 						$logrotate_file_chk[] = "$web_path/$web_name/subdomains/$web_subname/logs/error.log";
 						//$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
 						$num_generated_vhosts += $num_rows2;
