@@ -58,29 +58,31 @@ function get_remote_mail($a,$recipients){
 //			$rcpthosts_file .= "";
 		}else{
 			if( $panel_type == "cronjob"){
-				echo "\nUsing php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"]."...";
+				echo "\nUsing php dtc_HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"]."...";
 			}else{
-				$console .= "<br>Using php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"]."...";
+				$console .= "<br>Using php dtc_HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"]."...";
 			}
-			$httprequest = new HTTPRequest("$url");
+			$httprequest = new dtc_HTTPRequest("$url");
 			$lines = $httprequest->DownloadToStringArray();
-			$nline = sizeof($lines);
-			if(
-				(strstr($lines[0],"<dtc_backup_mx_domain_list>") &&
-				strstr($lines[$nline-1],"</dtc_backup_mx_domain_list>")
-				) ||
-				( $recipients == 1 && strstr($lines[0],"<dtc_backup_mx_recipient_list>") &&
-				strstr($lines[$nline-1],"</dtc_backup_mx_recipient_list>")
-				)
-			){
-				for($j=1;$j<$nline-1;$j++){
-					$rcpthosts_file .= $lines[$j]."\n";
-				}
-				$flag = true;
-				if( $panel_type == "cronjob"){
-					echo "success!\n";
-				}else{
-					$console .= "success!<br>";
+			if($lines != FALSE){
+				$nline = sizeof($lines);
+				if(
+					(strstr($lines[0],"<dtc_backup_mx_domain_list>") &&
+					strstr($lines[$nline-1],"</dtc_backup_mx_domain_list>")
+					) ||
+					( $recipients == 1 && strstr($lines[0],"<dtc_backup_mx_recipient_list>") &&
+					strstr($lines[$nline-1],"</dtc_backup_mx_recipient_list>")
+					)
+				){
+					for($j=1;$j<$nline-1;$j++){
+						$rcpthosts_file .= $lines[$j]."\n";
+					}
+					$flag = true;
+					if( $panel_type == "cronjob"){
+						echo "success!\n";
+					}else{
+						$console .= "success!<br>";
+					}
 				}
 			}
 		}
