@@ -1,5 +1,5 @@
 <?php
-
+                                                        
 function deleteTicketThread($delete_me){
 	global $pro_mysql_tik_queries_table;
 
@@ -178,6 +178,7 @@ function getCustomerInfoFromLogin($login){
 function drawNewAdminForm(){
 	global $conf_site_root_host_path;
 	global $conf_session_expir_minute;
+	global $conf_post_or_get;
 	global $lang;
 
 	global $pro_mysql_admin_table;
@@ -192,6 +193,7 @@ function drawNewAdminForm(){
 	global $pro_mysql_tik_queries_table;
 	global $pro_mysql_tik_cats_table;
 	global $pro_mysql_dedicated_table;
+	global $pro_mysql_custom_product_table;
 
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_dedicated_ips_table;
@@ -257,6 +259,31 @@ function drawNewAdminForm(){
 				$replied_by = "";
 			}
 			$out .= "<tr><td$bg valign=\"top\"><i>".$a["date"]." ".$a["time"]."</i>".$replied_by."</td><td$bg>".nl2br(htmlspecialchars(stripslashes($a["text"])))."</td></tr>";
+			// Display attachements
+			if($a["attach"] != ""){
+				$attachments = explode("|",$a["attach"]);
+				$natt = sizeof($attachments);
+				for($z=0;$z<$natt;$z++){
+					$att = $attachments[$z];
+					$qatt = "SELECT * FROM tik_attach WHERE id='$att';";
+					$ratt = mysql_query($qatt)or die("Cannot query $qatt line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+					$zn = mysql_num_rows($ratt);
+					if($zn != 1){
+						continue;
+					}
+					$at = mysql_fetch_array($ratt);
+					$binary = pack("H*" , $at["datahex"]);
+					$chment_size = smartByte(strlen($binary));
+					$out .= "<tr><td$bg valign=\"top\"><i>".htmlspecialchars($at["ctype_prim"])."/".htmlspecialchars($at["ctype_sec"])." ".$chment_size."<br>
+						".htmlspecialchars($at["filename"])."</i></td>";
+					// Show Imagick miniature if we have a gif, jpeg or PNG.
+					if($at["ctype_prim"] == "image" && ($at["ctype_sec"] == "jpeg" || $at["ctype_sec"] == "gif" || $at["ctype_sec"] == "png")){
+						$out .= "<td$bg><a target=\"_blank\" href=\"show_attachment.php?id=".$att."\"><img src=\"show_attachment.php?id=".$att."&minipic=yes\"></a></td></tr>";
+					}else{
+						$out .= "<td$bg><a target=\"_blank\" href=\"show_attachment.php?id=".$att."\">".htmlspecialchars($at["filename"])."</a></td></tr>";
+					}
+				}
+			}
 			if($a["request_close"] == "yes"){
 				$close_request = "yes";
 			}
@@ -268,7 +295,7 @@ function drawNewAdminForm(){
 		}else{
 			$out .= "<font color=\"#FF0000\">"._("No")."</font><br>";
 		}
-		$out .= "<form action=\"?\" method=\"post\">
+		$out .= "<form method=\"$conf_post_or_get\" action=\"?\" method=\"post\">
 		<input type=\"hidden\" name=\"subaction\" value=\"ticket_reply\">
 		<textarea cols=\"100\" rows=\"10\" wrap=\"physical\" name=\"ticketbody\"></textarea><br>
 		<input type=\"hidden\" name=\"tik_id\" value=\"".$_REQUEST["tik_id"]."\">
@@ -377,7 +404,7 @@ function drawNewAdminForm(){
 
 	// Draw the form for making a new admin
 	$add_a_user = "<h3>". _("Add a new user") ."</h3>
-<form name=\"addnewuser_frm\" action=\"?\" method=\"post\">
+<form method=\"$conf_post_or_get\" name=\"addnewuser_frm\" action=\"?\" method=\"post\">
 <input type=\"hidden\" name=\"newadminuser\" value=\"Ok\">
 ".dtcFormTableAttrs().
 dtcFormLineDraw(_("Login:"),"<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"newadmin_login\" value=\"\">").
@@ -395,7 +422,7 @@ dtcFromOkDraw()."
 	}
 	// Draw the list of users awaiting for an account
 	$waiting_new_users = "<h3>". _("User and domain waiting for addition:") ."</h3>";
-	$q = "SELECT * FROM $pro_mysql_new_admin_table ORDER BY date,time";
+	$q = "SELECT * FROM $pro_mysql_new_admin_table WHERE archive='no' ORDER BY date,time";
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n < 1){
@@ -459,13 +486,18 @@ dtcFromOkDraw()."
 			}
 			if($secpayconf_use_maxmind == "yes"){
 				$maxmind = unserialize($a["maxmind_output"]);
-				if($maxmind["riskScore"] >= 20){
+				if(isset($maxmind["riskScore"]) && $maxmind["riskScore"] >= 20){
 					$fnt = "<font color=\"red\">";
 					$fnt2 = "</font>";
 				}else{
 					$fnt = "";
 					$fnt2 = "";
 				}
+				if(isset($maxmind["riskScore"])){
+					$maxmind_riskScore = $maxmind["riskScore"];
+				}else{
+					$maxmind_riskScore = "N/A";
+				}
 				$waiting_new_users .= "<$td>"._("Risk score: ").$fnt.$maxmind["riskScore"].$fnt2."<br>";
 				if($maxmind["ip_isp"] == $maxmind["ip_org"]){
 					$waiting_new_users .= _("ISP: ").$maxmind["ip_isp"].", "."<br>";
@@ -482,9 +514,11 @@ dtcFromOkDraw()."
 				$waiting_new_users .= _("Country match: ").$fnt.$maxmind["countryMatch"]." (".$maxmind["countryCode"].")".$fnt2;
 				$waiting_new_users .= "</td>";
 			}
-			$waiting_new_users .= "<$td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("Edit") ."</a><br/>
-			<a href=\"?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". _("Add") ."</a><br/>
-			<a href=\"?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". _("Delete") ."</a></td>";
+			$waiting_new_users .= "<$td><table border=\"0\" cellspacing=\"1\" cellpadding=\"0\"><tr>
+			<td><a href=\"?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". dtcAddButton() ."</a></td>
+			<td><a href=\"?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". dtcDeleteButton() ."</a></td></tr>
+			<tr><td><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". dtcEditButton() ."</a></td>
+			<td><a href=\"?action=archive_waiting_user&reqadm_id=".$a["id"]."\">". dtcArchiveButton() ."</a></td></tr></table></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -656,12 +690,25 @@ dtcFromOkDraw()."
 					}
 				}
 				break;
+			case "custom":
+				$q2 = "SELECT * FROM $pro_mysql_custom_product_table WHERE id='".$a["renew_id"]."'";
+				$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+				if($n2 != 1){
+					$tmp = _("Cannot find custom service in database.");
+				}else{
+					$a2 = mysql_fetch_array($r2);
+					$tmp = $a2["owner"];
+				}
+				$heb_type = _("Custom:") ." ".$tmp;
+				break;
 			default:
 				echo "Renew type ".$a["heb_type"]." not implemented line ".__LINE__." file ".__FILE__;
 				break;
 			}
 			$waiting_new_users .= "<$td>$heb_type</td>";
-			$waiting_new_users .= "<$td style=\"white-space:nowrap\"><a href=\"?action=validate_renewal&id=".$a["id"]."\">". _("Validate") ."</a> <a href=\"?action=delete_renewal&id=".$a["id"]."\">". _("Del") ."</a></td>";
+			$waiting_new_users .= "<$td style=\"white-space:nowrap\">
+			<table border=\"0\" cellspacing=\"1\" cellpadding=\"0\"><tr>
+			                        <td><a href=\"?action=validate_renewal&id=".$a["id"]."\">". dtcAddButton() ."</a></td><td><a href=\"?action=delete_renewal&id=".$a["id"]."\">". dtcDeleteButton() ."</a></td></tr></table></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -751,7 +798,7 @@ dtcFromOkDraw()."
 		$ss = "";
 	}
 	$search = "<h3>". _("Search engine") ."</h3>
-<form name=\"search_me\" action=\"?\" method=\"get\">
+<form method=\"$conf_post_or_get\" name=\"search_me\" action=\"?\" method=\"get\">
 <input type=\"hidden\" name=\"search_query\" value=\"do\">
 ".dtcFormTableAttrs().
 dtcFormLineDraw("","
