@@ -90,6 +90,7 @@ function drawDTCConfigMenu(){
 function configEditorTemplate ($dsc,$conftype="config"){
 	global $pro_mysql_config_table;
 	global $pro_mysql_secpayconf_table;
+	global $conf_post_or_get;
 	$out = "";
 
 	if($conftype == "config"){
@@ -146,7 +147,7 @@ function configEditorTemplate ($dsc,$conftype="config"){
 	}
 
 	$out .= dtcFormTableAttrs();
-	$out .= "<form action=\"?\">
+	$out .= "<form method=\"$conf_post_or_get\" action=\"?\">
 <input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."\">$fw";
 	for($i=0;$i<$n;$i++){
 		$fld = $prefix.$keys[$i];
@@ -425,6 +426,7 @@ function drawIPPoolConfig(){
 	global $pro_mysql_dedicated_ips_table;
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_cronjob_table;
+	global $conf_post_or_get;
 
 	global $rub;
 	global $sousrub;
@@ -504,7 +506,7 @@ function drawIPPoolConfig(){
 			$a = mysql_fetch_array($r);
 			$out .= "<h3>"._("Custom RDNS entries for the IP pool")." " .$a["location"] . " (" . $a["ip_addr"] . " / " . $a["netmask"] . "):</h3>";
 			$out .= _("The following will be appened at the end of the reverse zone file.");
-			$out .= "<form action=\"?\">
+			$out .= "<form method=\"$conf_post_or_get\" action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"$rub\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"editpool\" value=\"".$_REQUEST["editpool"]."\">
@@ -572,6 +574,7 @@ function drawTicketConfig(){
 	global $conf_all_customers_list_domain;
 	global $conf_all_customers_list_email;
 	global $conf_enforce_adm_encryption;
+	global $conf_post_or_get;
 	global $pro_mysql_list_table;
 	global $pro_mysql_domain_table;
 	global $pro_mysql_client_table;
@@ -590,7 +593,7 @@ function drawTicketConfig(){
 
 	$all_lists = array();
 	$domains[] = _("no list selected");
-	$q = "SELECT * FROM $pro_mysql_list_table WHERE domain='$conf_all_customers_list_domain';";
+	$q = "SELECT * FROM $pro_mysql_list_table WHERE domain='$conf_all_customers_list_domain' ORDER BY name;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." mysql said ".mysql_error());
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
@@ -649,7 +652,10 @@ function drawTicketConfig(){
 			// Then we get a list of all the users and we subscribe them
 			$old_file = "";
 			$addr_list = "";
+			// This is absolutely all customer, all time, even deleted admins
 			$q = "SELECT DISTINCT email FROM $pro_mysql_client_table ORDER BY email";
+			// This is all customer having a domain name (so, shared accounts)
+			//$q = "SELECT DISTINCT clients.email FROM clients,admin,domain WHERE clients.id=admin.id_client AND domain.owner=admin.adm_login ORDER BY email";
 			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
 			for($i=0;$i<$n;$i++){
@@ -674,7 +680,7 @@ function drawTicketConfig(){
 			}
 		}
 	}
-	$out .= "<form action=\"?\">
+	$out .= "<form method=\"$conf_post_or_get\" action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"$rub\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"action\" value=\"resubscript_all_users\">
@@ -772,6 +778,21 @@ function drawFTPBacupConfig(){
 		"forward" => array("rub","sousrub"),
 		"cols" => array(
 			"ftp_backup_activate" => array(
+				"legend" => _("Activate Backups:"),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"ftp_7z_mode" => array(
+				"legend" => _("Activate 7z compression instead of gzip:"),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"ftp_7z_level" => array(
+				"legend" => _("7z compression level:"),
+				"type" => "popup",
+				"values" => array("fastest","fast","normal","max","ultra"),
+				"display_replace" => array(_("Fastest"),_("Fast"),_("Normal"),_("Maximum"),_("Ultra"))),
+			"ftp_ftp_mode" => array(
 				"legend" => _("Activate FTP Backups:"),
 				"type" => "radio",
 				"values" => array("yes","no"),
@@ -801,7 +822,20 @@ function drawFTPBacupConfig(){
 				"legend" => _("Use active FTP connection to backup server:"),
 				"type"=>"radio",
 				"values" => array("yes","no"),
-				"display_replace" => array(_("Yes"),_("No")))));
+				"display_replace" => array(_("Yes"),_("No"))),
+			"ftp_ssh_mode" => array(
+				"legend" => _("Activate SSH Backups:"),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"ftp_backup_host_ssh" => array(
+				"legend" => _("Hostname:"),
+				"type" => "text",
+				"size" => "30"),
+			"ftp_backup_dest_folder_ssh" => array(
+				"legend" => _("SSH Destination folder:"),
+				"type" => "text",
+				"size" => "30")));
 	return configEditorTemplate ($dsc);
 }
 
@@ -1076,9 +1110,11 @@ function drawVPSServerConfig(){
 
 function drawRegistrySelection(){
 	global $pro_mysql_registry_table;
+	global $conf_post_or_get;
+
 	$out = "<h3>". _("Registry selection") ."</h3>";
 	$out .= "";
-	$out .= "<form action=\"?\">
+	$out .= "<form method=\"$conf_post_or_get\" action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"".$_REQUEST["rub"]."\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"action\" value=\"add_mx_trigger_backup\">
@@ -1154,6 +1190,11 @@ function drawGeneralConfig(){
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"post_or_get"  => array(
+				"legend" => _("Type of form requsts: "),
+				"type" => "radio",
+				"values" => array("POST","GET"),
+				"display_replace" => array("POST","GET" . _(" (insecure, but useful for scripting DTC)"))),
 			"session_expir_minute" => array(
 				"legend" => _("User session expire time (min): "),
 				"type" => "text",
@@ -1170,7 +1211,12 @@ function drawGeneralConfig(){
 			"selling_conditions_url" => array(
 				"legend" => _("Terms and Conditions URL: "),
 				"type" => "text",
-				"size" => "40")));
+				"size" => "40")),
+			"send_cron_alert" => array(
+				"legend" => _("Send mail to admin when an error occurs in dtc cron:"),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))));
 	$out .= configEditorTemplate ($dsc);
 
 	$dsc = array(
@@ -1188,6 +1234,11 @@ function drawGeneralConfig(){
 				"legend" => _("Use cyrus: "),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"use_sieve" => array(
+				"type" => "radio",
+				"legend" => _("Use sieve: "),
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
 			"use_advanced_lists_tunables" => array(
 				"type" => "radio",
 				"legend" => _("Show advanced mailing list options: "),
@@ -1242,6 +1293,10 @@ function drawGeneralConfig(){
 				"type" => "radio",
 				"display_replace" => array("Roundcube","Squirrelmail"),
 				"values" => array("roundcube","squirrelmail")),
+			"autogen_webmail_protocol" => array(
+				"legend" => _("Protocol to use for the /webmail alias: "),
+				"type" => "radio",
+				"values" => array("http:","https:")),
 			"apache_directoryindex" => array(
 				"legend" => _("Apache DirectoryIndex Config: "),
 				"size" => "50",
@@ -1645,6 +1700,21 @@ function drawDTCpayConfig(){
 				"display_replace" => array(_("Yes"),_("No"))) ));
 	$out .= configEditorTemplate($dsc);
 
+	$dsc = array(
+		"title" => _("Use vps, dedicated and custom productd as renewall products"),
+		"action" => "use_products_for_renewal",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"use_products_for_renewal" => array(
+				"legend" => _("Use vps, dedicated and custom productd as renewall products: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))) ));
+	$out .= configEditorTemplate($dsc,"secpay");
+	$out .= _("When this option is Yes, the client can renew his vps, 
+		dedicated or custom product with the plan that already has, allowing
+		renewall of products that don't have renewal products")."<br>";
+
 	$dsc = array(
 		"title" => _("Affiliation"),
 		"action" => "affiliate_edit",
