@@ -32,10 +32,10 @@ function drawRrdtoolGraphs (){
 <tr><td><IFRAME src=\"cpugraph.php\" width=\"100%\" height=\"318\"></iframe></td></tr>
 <tr><td><h3>". _("Memory and Swap Usage ") ."</h3></td><tr>
 <tr><td><IFRAME src=\"memgraph.php\" width=\"100%\" height=\"318\"></iframe></td></tr>
-<tr><td><h3>". _("Mail Queue graph") ."</h3></td><tr>
+<tr><td><h3>". _("Mail Queue Graph") ."</h3></td><tr>
 <tr><td><IFRAME src=\"mailgraph.php\" width=\"100%\" height=\"318\"></iframe></td></tr>";
 		if( file_exists("/usr/sbin/mailgraph")){
-			$out .= "<tr><td><h3>". _("Mail Queue statistics") ."</h3></td><tr>";
+			$out .= "<tr><td><h3>". _("Mail Queue Statistics") ."</h3></td><tr>";
 			$out .= "<tr><td><IFRAME src=\"/cgi-bin/mailgraph.cgi\" width=\"100%\" height=\"388\"></iframe></td></tr>";
 		}
 		$out .= "</table></center>";
