@@ -15,7 +15,7 @@ function drawAdminMonitor (){
 	$nr = mysql_num_rows($r);
 	$out .= '<br><table border="1" width="100%" height="1" cellpadding="1" cellspacing="1">';
 	$out .=
-"<tr><td><b>". _("User") ."</b></td><td><b>". _("Transfer") ." / ". _("BW Quota") ."</b></td><td><b>". _("Transfer per month") ."</b></td><td><b>". _("Disk usage") ." / ". _("Quota") ."</b></td></tr>";
+"<tr><td><b>". _("User") ."</b></td><td><b>". _("Transfer") ." / ". _("BW Quota") ."</b></td><td><b>". _("Transfer per Month") ."</b></td><td><b>". _("Disk Usage") ." / ". _("Quota") ."</b></td></tr>";
 	$total_box_transfer = 0;
 	$total_box_hits = 0;
 	for($i=0;$i<$nr;$i++){
@@ -84,7 +84,7 @@ function drawAdminMonitor (){
 			$out .= "<td$back>".drawPercentBar($transfer,$ar["bw_quota_per_month_gb"]*1024*1024*1024,"no")."<br>
 ".smartByte($transfer)." / ".smartByte($ar["bw_quota_per_month_gb"]*1024*1024*1024)." ($total_hits hits)</td>";
 			// Per month transfer graph
-			$out .= "<td$back><img width=\"120\" height=\"48\" src=\"bw_per_month.php?cid=".$ar["id"]."\"></td>";
+			$out .= "<td$back><img width=\"120\" height=\"48\" src=\"bw_per_month.php?adm_login=".$ar2["adm_login"]."&adm_pass=".$ar2["adm_pass"]."\"></td>";
 			// Share hosing hard disk space
 			$out .= "<td$back>".drawPercentBar($du,$ar["disk_quota_mb"]*1024*1024,"no")."<br>
 ".smartByte($du)." / ".smartByte($ar["disk_quota_mb"]*1024*1024)."</td></tr>";
@@ -112,7 +112,7 @@ function drawAdminMonitor (){
 //fetchAdminStats($admin)
 	}
 	$out .= "</table>";
-	$out .= _("Server accounted transfers this month: ").smartByte($total_box_transfer)." ($total_box_hits hits)";
+	$out .= _("Total transfer this month: ").smartByte($total_box_transfer)." ($total_box_hits hits)";
 	return $out;
 }
 
