@@ -104,6 +104,7 @@ function listTypePopup(){
 	global $admlist_type;
 	global $cur_admlist_type;
 	global $panel_type;
+	global $conf_post_or_get;
 
 	if($panel_type!="cronjob"){
 		if(isset($_REQUEST["admlist_type"]) && $_REQUEST["admlist_type"] != ""){
@@ -130,7 +131,7 @@ function listTypePopup(){
 	}
 
 	$admins = "<div class=\"box_wnb_nb_content\">
-<div style=\"white-space: nowrap\" nowrap><form action=\"?\"><font size=\"-2\">". _("Display and sort by:")  ."<br>
+<div style=\"white-space: nowrap\" nowrap><form method=\"$conf_post_or_get\" action=\"?\"><font size=\"-2\">". _("Display and sort by:")  ."<br>
 <select class=\"box_wnb_nb_input\" name=\"admlist_type\">
 <option value=\"Logins\"$selectedlist_logins>" . _("Logins") . "
 <option value=\"Names\"$selectedlist_name>" . _("Names") . "
@@ -162,6 +163,7 @@ function adminList($password=""){
 	global $panel_type;
 	global $cur_admlist_type;
 	global $conf_mysql_db;
+	global $idn;
 
 	if($password != ""){
 		$zepass = $password;
@@ -291,8 +293,9 @@ function adminList($password=""){
 				$linkadm_login = $row2["adm_login"];
 				$linkadm_pass = $row2["adm_pass"];
 				$admins .= "<a href=\"?adm_login=$linkadm_login&adm_pass=$zepass$added_rub\">$domain_name</a><br>";
+				$domain_idn = $idn->decode($domain_name);
 				$dsc["admins"][] = array(
-					"text" => $domain_name,
+					"text" => $domain_idn,
 					"adm_login" => $linkadm_login,
 					"adm_pass" => "$zepass");
 			}
