@@ -206,8 +206,9 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "set_vhost_custom_direct
 }
 
 if(isset($_REQUEST["newdomain"]) && $_REQUEST["newdomain"] == "Ok"){
-	if(isHostname($_REQUEST["newdomain_name"])){
-		addDomainToUser($adm_login,$adm_pass,$_REQUEST["newdomain_name"]);
+	$newdomain_idn = $idn->encode($_REQUEST["newdomain_name"]);
+	if(isHostname($newdomain_idn)){
+		addDomainToUser($adm_login,$adm_pass,$newdomain_idn);
 		triggerDomainListUpdate();
 	}else{
 		echo "<font color=\"red\">Hostname is not a valid domain name!</font>";
@@ -315,8 +316,8 @@ if(isset($_REQUEST["newadminuser"]) && $_REQUEST["newadminuser"]=="Ok"){
 	// Add user in database
 	if($commit_flag != "no"){
 		$adm_query = "INSERT INTO $pro_mysql_admin_table
-(adm_login        ,adm_pass         ,path            )VALUES
-('".$_REQUEST["newadmin_login"]."', '".$_REQUEST["newadmin_pass"]."','$newadmin_path') ";
+(adm_login        ,adm_pass         ,path            , shared_hosting_security)VALUES
+('".$_REQUEST["newadmin_login"]."', '".$_REQUEST["newadmin_pass"]."','$newadmin_path', 'sbox_aufs') ";
 		mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 	}else{
 		echo $submit_err;
@@ -329,6 +330,16 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="delete_waiting_user"){
 	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 }
 
+if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="archive_waiting_user"){
+	$q = "UPDATE $pro_mysql_new_admin_table SET archive='yes' WHERE id='".$_REQUEST["reqadm_id"]."';";
+	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+}
+
+if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="archive_waiting_user"){
+	$q = "UPDATE $pro_mysql_new_admin_table SET archive='yes' WHERE id='".$_REQUEST["reqadm_id"]."';";
+	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+}
+
 // action=valid_waiting_user&reqadm_login=tom
 if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="valid_waiting_user"){
 	validateWaitingUser($_REQUEST["reqadm_id"]);
