@@ -276,7 +276,7 @@ function sendSharedHostingReminderEmail($remaining_days,$file,$send_webmaster_co
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n2 = mysql_num_rows($r2);
 		if($n2 != 1){
-			sendAdminWarning("Could not find id client ".$admin["id_client"]." for admin ".$vps["owner"]." line ".__LINE__." file ".__FILE__);
+			sendAdminWarning("Could not find id client ".$admin["id_client"]." for admin ".$admin["adm_login"]." line ".__LINE__." file ".__FILE__);
 			continue;
 		}
 		$client = mysql_fetch_array($r2);
@@ -324,6 +324,7 @@ function sendCustomProductsReminderEmail($remaining_days,$file,$cust_heb_type_id
 	global $pro_mysql_client_table;
 	global $pro_mysql_custom_product_table;
 	global $conf_webmaster_email_addr;
+	global $conf_custom_renewal_lastwarning;
 
 	global $conf_message_subject_header;
 	global $dtcshared_path;
@@ -338,6 +339,12 @@ function sendCustomProductsReminderEmail($remaining_days,$file,$cust_heb_type_id
 	for($i=0;$i<$n;$i++){
 		$cust_pr = mysql_fetch_array($r);
 
+		// Execute custom action if it reaches the shutdown warning
+		if($remaining_days == -$conf_custom_renewal_lastwarning){
+			//remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"shutdown_vps");
+			executeCustomActions($cust_heb_type_id, 'expire', $cust_pr["id"]);
+		}
+
 		// Get the admin
 		$q2 = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$cust_pr["owner"]."';";
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
