@@ -5,13 +5,17 @@ if [ -z ""$MAIN_DIR ]; then
 	MAIN_DIR=/var/www/sites
 fi
 if [ -z ""$CHROOT_PATH ]; then
-	CHROOT_PATH=/var/www/chroot
+	CHROOT_PATH=/var/lib/dtc/chroot_template
 fi
 pushd $MAIN_DIR
 for i in */*/subdomains/*/
 do 
 	echo "=> Updating chroot in $i..."
-	cp -fupRv $CHROOT_PATH/* $i
+	if [ "`uname -s`" == "FreeBSD" ] ; then		# same for OSX?
+		cp -fpRv $CHROOT_PATH/* $i
+	else
+		cp -fupRv $CHROOT_PATH/* $i
+	fi
 	# remove un-needed directories
 	rm -rf $i/etc/pam.d
 	rm -rf $i/etc/security
