@@ -49,25 +49,30 @@ if ( count($subs) >= 2) { // FIXME watch out: this malfunctions with IP addresse
 	$domain = $serverdomain;
 }
 
-
-// FIXME: need to include DTC validation functions so we can use isMailbox here instead
-// relevant file: dtc/shared/drawlib/dtc_functions.php
-$affiliate = $_REQUEST["affiliate"];
-if (preg_match("/[^a-z0-9-_]/","",$affiliate)) die ( _("Affiliate can only have lowercase letters, numbers and - _") );
-
-$returnurl = $_REQUEST["return"];
-if ($returnurl) {
-	if (preg_match("/[^\?&]/","",$returnurl)) die ( _("Return URL can't have query string parameters") );
-	if (substr($returnurl,0,1) != "/") $returnurl = "/" . $returnurl;
-} else {
-	$returnurl = "/";
-}
-
 $panel_type="client";
 require_once("../shared/autoSQLconfig.php");
 // All shared files between DTCadmin and DTCclient
 require_once("$dtcshared_path/dtc_lib.php");
 
+// FIXME: need to include DTC validation functions so we can use isMailbox here instead
+// relevant file: dtc/shared/drawlib/dtc_functions.php
+$affiliate = $_REQUEST["affiliate"];
+if (preg_match("/[^a-z0-9-_]/",$affiliate)) die ( _("Affiliate can only have lowercase letters, numbers and - _") );
+
+$returnurl = $_REQUEST["return"];
+if ($returnurl) {
+	if(substr($returnurl,0,1) == "/"){
+		$check = substr($returnurl,1);
+	}else{
+		$check = $returnurl;
+	}
+	if(checkSubdomainFormat($check) === false){
+		die ( _("Wrong affiliation return URL format: will not proceed."));
+	}
+	if (substr($returnurl,0,1) != "/") $returnurl = "/" . $returnurl;
+} else {
+	$returnurl = "/";
+}
 
 if ($conf_affiliate_return_domain) {
 	$returnurl = "http://" . $conf_affiliate_return_domain . $returnurl;
