@@ -20,6 +20,11 @@ function register_user($adding_service="no"){
 
 	global $gettext_lang;
 
+	global $conf_dtc_system_username;
+	global $pro_mysql_domain_table;
+	global $pro_mysql_dedicated_table;
+	global $pro_mysql_custom_product_table;
+
 	get_secpay_conf();
 
 	// Check if all fields are blank, in wich case don't display error
@@ -66,7 +71,7 @@ function register_user($adding_service="no"){
 		$ret["mesg"] = _("User login format incorrect. Username must contain only letters and numbers and contain 4 to 16 characters.") ;
 		return $ret;
 	}
-	if($_REQUEST["reqadm_login"] == "root" || $_REQUEST["reqadm_login"] == "debian-sys-maint"){
+	if($_REQUEST["reqadm_login"] == "root" || $_REQUEST["reqadm_login"] == "debian-sys-maint" || $_REQUEST["reqadm_login"] == $conf_dtc_system_username){
 		$ret["err"] = 2;
 		$ret["mesg"] = _("Username invalid: please choose a name other than root or debian-sys-maint") ;
 		return $ret;
@@ -89,12 +94,37 @@ function register_user($adding_service="no"){
 	}
 
 	// If shared or ssl hosting or custom with domain, we MUST do type checkings
-	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl" || $db_product["heb_type"] == "dedicated" || ($db_product["heb_type"] == "custom" && $db_product["reqdomain"] == "yes")){
+	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl" || $db_product["heb_type"] == "server" || ($db_product["heb_type"] == "custom" && $db_product["reqdomain"] == "yes")){
 		if(!isHostnameOrIP($_REQUEST["domain_name"].$_REQUEST["domain_tld"])){
 			$ret["err"] = 2;
 			$ret["mesg"] = _("Domain name seems to be incorrect.") ;
 			return $ret;
 		}
+		// check duplicated domains
+		$heb_type_tables = array("shared" => $pro_mysql_domain_table,
+		    "ssl" => $pro_mysql_domain_table,
+		    "server" => $pro_mysql_dedicated_table,
+		    "custom" => $pro_mysql_custom_product_table);
+		$heb_type_fields = array("shared" => "name",
+		    "ssl" => "name",
+		    "server" => "server_hostname",
+		    "custom" => "domain");
+		$q = "SELECT ".$heb_type_fields[$db_product["heb_type"]]." FROM ".$heb_type_tables[$db_product["heb_type"]]." WHERE ".$heb_type_fields[$db_product["heb_type"]]."='".$_REQUEST["domain_name"].$_REQUEST["domain_tld"]."';";
+		$r = mysql_query($q)or die("Cannot query  \"$q\" !!! Line: ".__LINE__." File: ".__FILE__." MySQL said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n > 0){
+			$ret["err"] = 3;
+			$ret["mesg"] = _("Domain name already taken. Try again.") ;
+			return $ret;
+		}
+		$q = "SELECT domain_name FROM $pro_mysql_new_admin_table WHERE domain_name='".$_REQUEST["domain_name"].$_REQUEST["domain_tld"]."';";
+		$r = mysql_query($q)or die("Cannot query  \"$q\" !!! Line: ".__LINE__." File: ".__FILE__." MySQL said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n > 0){
+			$ret["err"] = 3;
+			$ret["mesg"] = _("Domain name already taken. Try again.") ;
+			return $ret;
+		}
 	// If not a shared, a dedicated or ssl account, it's a VPS or custom without domain:
 	// we don't care if it's umpty, but we take care of mysql insertion anyway
 	// so if there is a domain name, then we check it's consistency, but we don't
@@ -475,6 +505,7 @@ $vps_mail_add1
 function registration_form(){
 	global $conf_this_server_country_code;
         global $conf_skin;
+        global $conf_post_or_get;
 
 	global $pro_mysql_product_table;
 	global $pro_mysql_vps_ip_table;
@@ -620,7 +651,7 @@ function registration_form(){
 	if(isset($_REQUEST["custom_notes"]))	$frm_custom_notes = htmlspecialchars($_REQUEST["custom_notes"]);
 	else	$frm_custom_notes = "";
 
-	if($heb_type == "all" || $heb_type == "shared" || $heb_type == "ssl"){
+	if($heb_type == "all" || $heb_type == "shared" || $heb_type == "server" || $heb_type == "ssl"){
 		$domname_hidden = " style=\"white-space:nowrap;\" ";
 	}else{
 		$domname_hidden = " style=\"display:none;visibility:hidden;white-space:nowrap;\" ";
@@ -901,7 +932,7 @@ function hostingProductChanged(){
 </script><br>
 <br>
 <i>" . _("Fields with a <font color=\"red\">*</font> are mandatory.") . "</i><br>
-<form name=\"newuser_form\" action=\"?\" methode=\"post\">
+<form name=\"newuser_form\" action=\"?\" method=\"$conf_post_or_get\">
 <input type=\"hidden\" name=\"action\" value=\"new_user_request\">
 <table>
 <tr>
