@@ -10,10 +10,12 @@ function renew_form(){
 	global $pro_mysql_vps_table;
 	global $pro_mysql_dedicated_table;
 	global $pro_mysql_vps_server_table;
+	global $pro_mysql_custom_product_table;
 
 	global $conf_webmaster_email_addr;
 	global $conf_message_subject_header;
 	global $conf_this_server_country_code;
+	global $conf_post_or_get;
 
 	global $secpayconf_currency_letters;
 
@@ -241,6 +243,24 @@ function renew_form(){
 		$ax = mysql_fetch_array($r);
 		$country = $ax["country_code"];
 		break;
+	case "custom":
+		if(!isRandomNum($_REQUEST["custom_id"])){
+			$ret["err"] = 3;
+			$ret["mesg"] = "<font color=\"red\">Custom id is not a valid number!</font>";
+			return $ret;
+		}
+		$client_id = $_REQUEST["custom_id"];
+		$q = "SELECT country_code FROM $pro_mysql_custom_product_table WHERE id='".$_REQUEST["custom_id"]."';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." mysql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$ret["err"] = 3;
+			$ret["mesg"] = "<font color=\"red\">Cannot find custom service country</font>";
+			return $ret;
+		}
+		$ax = mysql_fetch_array($r);
+		$country = $ax["country_code"];
+		break;
 	default:
 		die("Renew type unknown line ".__LINE__." file ".__FILE__);	// To be implemented for other means!
 		break;
@@ -384,7 +404,7 @@ Service country: $country
 			$out = _("After renewal, you will have") . ": " . $after_upgrade_remaining . " " .$secpayconf_currency_letters . "<br><br>";
 
 			// Check for confirmation
-			$frm_start = "<form action=\"?\">
+			$frm_start = "<form method=\"$conf_post_or_get\" action=\"?\">
 <input type=\"hidden\" name=\"action\" value=\"renew_myaccount\">
 ";
 			$out .= _("You have sufficient funds in your account. Press the confirm button and your order will be processed.") ."<br><br>
