@@ -10,9 +10,9 @@ else
 fi
 
 # Copy all the terminfo stuufs
-cp -f /etc/terminfo ${DEST}/etc
-cp -f /usr/share/terminfo ${DEST}/usr/share
-cp -f /lib/terminfo ${DEST}/lib
+cp -rf /etc/terminfo ${DEST}/etc
+cp -rf /usr/share/terminfo ${DEST}/usr/share
+cp -rf /lib/terminfo ${DEST}/lib
 cp -f /usr/bin/xterm ${DEST}/usr/bin
 cp -f /usr/bin/lxterm ${DEST}/usr/bin
 cp -f /usr/bin/resize ${DEST}/usr/bin
@@ -27,15 +27,15 @@ cp -f /bin/gzip ${DEST}/bin
 cp -f /usr/bin/wget ${DEST}/bin
 
 # needed by wget
-cp -f /lib/libnss_dns.so.2 ${DEST}/lib
+cp -rf /lib/libnss_dns.so.2 ${DEST}/lib
 
 # nvi
-cp -f /etc/alternatives ${DEST}/etc
+cp -rf /etc/alternatives ${DEST}/etc
 cp -f /usr/share/vi ${DEST}/usr/share
 cp -f /usr/bin/nvi ${DEST}/usr/bin
 
 # joe
-cp -f /etc/joe ${DEST}/etc
+cp -rf /etc/joe ${DEST}/etc
 cp -f /usr/bin/jstar ${DEST}/usr/bin
 cp -f /usr/bin/rjoe ${DEST}/usr/bin
 cp -f /usr/bin/jpico ${DEST} /usr/bin
