@@ -1,4 +1,6 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+<?php
+header("HTTP/1.0 404 Not Found");
+?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
@@ -40,16 +42,10 @@ website home page</a>
 </p>
 </div>
 <div class="footer">
-This website server is powered by Domain Technologie Control (DTC),
-an open-source control panel<br />
-<span class="italics">
-Most of code done by:
-<a target="_blank" href="http://thomas.goirand.fr">Thomas GOIRAND</a>, under
-<a target="_blank" href="http://www.gnu.org">LGPL</a>. Please visit
-<a target="_blank" href="http://gplhost.com/hosting-vps.html">GPLHost hosting VPS services</a> and
-<a target="_blank" href="http://gplhost.com/software-dtc.html">DTC GPL control panel home</a>
-for more info.
-</span>
+	<p>This website server is powered by Domain Technologie Control (DTC), the open-source control panel.</p>
+	<p><em>
+		Get your DTC setup for <strong>free</strong> with one of our <strong><a target="_blank" href="http://gplhost.com/hosting-vps.html" title="Virtual private server hosting" >VPS servers</a></strong> and dedicated hosting services; visit the <a target="_blank" href="http://gplhost.com/software-dtc.html">DTC control panel</a> to learn more and download it for your server.
+	</em></p>
 </div>
 </div>
 </div>
