@@ -7,7 +7,7 @@ function helpLink($link){
 	}else{
 		$helpimg_src = "gfx/help.png";
 	}
-	$out = "<a target=\"_blank\" href=\"http://dtcsupport.gplhost.com/$link\"><img border=\"0\" src=\"$helpimg_src\"</a>";
+	$out = "<a target=\"_blank\" href=\"http://dtcsupport.gplhost.com/$link\"><img border=\"0\" src=\"$helpimg_src\"></a>";
 	return $out;
 }
 
@@ -116,6 +116,28 @@ function dtcAddButton(){
 	return $delete;
 }
 
+function dtcEditButton(){
+	global $gfx_icn_path_editme;
+
+	if(isset($gfx_icn_path_editme)){
+		$delete = "<div class=\"btn_p_container\" onMouseOver=\"this.className='btn_p_container-hover';\" onMouseOut=\"this.className='btn_p_container';\"><input type=\"image\" src=\"".$gfx_icn_path_editme."\"></div>";
+	}else{
+		$delete = "<input type=\"image\" src=\"gfx/stock_add_24.png\">";
+	}
+	return $delete;
+}
+
+function dtcArchiveButton(){
+	global $gfx_icn_path_compress;
+
+	if(isset($gfx_icn_path_compress)){
+		$delete = "<div class=\"btn_p_container\" onMouseOver=\"this.className='btn_p_container-hover';\" onMouseOut=\"this.className='btn_p_container';\"><input type=\"image\" src=\"".$gfx_icn_path_compress."\"></div>";
+	}else{
+		$delete = "<input type=\"image\" src=\"gfx/stock_add_24.png\">";
+	}
+	return $delete;
+}
+
 function dtcFromOkDraw($delete_form=""){
 	$out = "<tr><td>&nbsp;</td><td>".dtcApplyButton()."$delete_form</td></tr>";
 	return $out;
@@ -172,6 +194,8 @@ function dtcDatagrid($dsc){
 
 	global $gfx_form_entry_label_background;
 	global $conf_enforce_adm_encryption;
+	global $conf_post_or_get;
+	global $idn;
 
 	$nbr_forwards = sizeof($dsc["forward"]);
 	$keys_fw = array_keys($dsc["forward"]);
@@ -233,9 +257,9 @@ function dtcDatagrid($dsc){
 						$happen = "";
 					}
 					if( $dsc["cols"][ $keys[$i] ]["type"] == "password" && isset($dsc["cols"][ $keys[$i] ]["encrypt"]) && $dsc["cols"][ $keys[$i] ]["encrypt"] == "yes" && $conf_enforce_adm_encryption == "yes"){
-						$vals .= "SHA1('".$_REQUEST[ $keys[$i] ].$happen."')";
+						$vals .= "SHA1('".mysql_real_escape_string($_REQUEST[ $keys[$i] ]).$happen."')";
 					}else{
-						$vals .= "'".$_REQUEST[ $keys[$i] ].$happen."'";
+						$vals .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ]).$happen."'";
 					}
 					$added_one = "yes";
 					break;
@@ -304,9 +328,9 @@ function dtcDatagrid($dsc){
                                                 $vals .= ", ";
                                         }
 					if( isset($dsc["cols"][ $keys[$i] ]["encrypt"]) && $dsc["cols"][ $keys[$i] ]["encrypt"] == "yes" && $conf_enforce_adm_encryption){
-	                                        $vals .= " ".$keys[$i]."=SHA1('".$_REQUEST[ $keys[$i] ]."') ";
+	                                        $vals .= " ".$keys[$i]."=SHA1('".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."') ";
 					}else{
-	                                        $vals .= " ".$keys[$i]."='".$_REQUEST[ $keys[$i] ]."' ";
+	                                        $vals .= " ".$keys[$i]."='".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."' ";
 					}
                                         $added_one = "yes";
 					// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
@@ -326,14 +350,14 @@ function dtcDatagrid($dsc){
 						$arr_request[] = $req_field.":".$req_value;
 					}
 					$txt_request = join("|",$arr_request);
-					$vals .= " ".$keys[$i]."='".$txt_request."' ";
+					$vals .= " ".$keys[$i]."='".mysql_real_escape_string($txt_request)."' ";
 					$added_one = "yes";
 					break;
 				default:
 					if($added_one == "yes"){
 						$vals .= ", ";
 					}
-					$vals .= " ".$keys[$i]."='".$_REQUEST[ $keys[$i] ]."' ";
+					$vals .= " ".$keys[$i]."='".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."' ";
 					$added_one = "yes";
 					break;
 				}
@@ -433,7 +457,7 @@ function dtcDatagrid($dsc){
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		$out .= "<tr><form name=\"".$dsc["action"]."_edit_frm_$i\" action=\"?\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_edit\">";
+		$out .= "<tr><form name=\"".$dsc["action"]."_edit_frm_$i\" action=\"?\" method=\"$conf_post_or_get\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_edit\">";
 		if(($i % 2) == 1 && isset($gfx_form_entry_label_background)){
 			$tdclass = "dtcDatagrid_table_flds_alt";
 			$input_class = "dtcDatagrid_input_alt_color";
@@ -638,7 +662,11 @@ function dtcDatagrid($dsc){
 				if($dsc["cols"][ $the_name ]["display"] == "yes"){
 					$out .= "<td class=\"$tdclass\">";
 					$out .= $id_hidden;
-					$out .= $db_value;
+					if ($the_name == 'name') {
+						$out .= $idn->decode($db_value);
+					} else {
+						$out .= $db_value;
+					}
 					$out .= "</td>";
 				}else{
 					$out .= $id_hidden;
@@ -723,7 +751,7 @@ function dtcDatagrid($dsc){
 		if(isset($dsc["skip_deletion"]) && $dsc["skip_deletion"] == "yes"){
 			$out .= "<td class=\"$tdclass\">&nbsp;</td></tr>";
 		}else{
-			$out .= "<td class=\"$tdclass\"><form action=\"?\">$fw$id_hidden
+			$out .= "<td class=\"$tdclass\"><form method=\"$conf_post_or_get\" action=\"?\">$fw$id_hidden
 			<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_delete\">".dtcDeleteButton()."</form></td>";
 			$out .= "</form></tr>";
 		}
@@ -737,7 +765,7 @@ function dtcDatagrid($dsc){
 			$input_class = "dtcDatagrid_input_color";
 		}
 		// Write the NEW stuff...
-		$out .= "<tr><form name=\"".$dsc["action"]."_new_frm\" id=\"".$dsc["action"]."_new_frm\" action=\"?\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new\">";
+		$out .= "<tr><form method=\"$conf_post_or_get\" name=\"".$dsc["action"]."_new_frm\" id=\"".$dsc["action"]."_new_frm\" action=\"?\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new\">";
 		for($j=0;$j<$nbr_fld;$j++){
 			$the_fld = $dsc["cols"][ $keys[$j] ];
 			switch($the_fld["type"]){
@@ -884,6 +912,7 @@ function dtcDatagrid($dsc){
 
 function dtcListItemsEdit($dsc){
 	global $adm_pass;
+	global $conf_post_or_get;
 
 	$out = "<h3>".$dsc["title"]."</u></b></h3>";
 
@@ -949,6 +978,12 @@ function dtcListItemsEdit($dsc){
 		$commit_flag = "yes";
 		$commit_err = "";
 		for($i=0;$i<$nbr_fld;$i++){
+			// assign a "fixup" function to sanitize/alter the value, eg. 'strtolower'
+			if( isset($dsc["cols"][ $keys[$i] ]["fixup"]) ){
+				if( function_exists($dsc["cols"][ $keys[$i] ]["fixup"]) ){
+					$_REQUEST[ $keys[$i] ] = $dsc["cols"][ $keys[$i] ]["fixup"]( $_REQUEST[ $keys[$i] ] );
+				}
+			}
 			switch($dsc["cols"][ $keys[$i] ]["type"]){
 			case "popup":
 			case "radio":
@@ -1578,7 +1613,7 @@ function dtcListItemsEdit($dsc){
 		if(isset($dsc["max_item"]) && $current_num_items >= $dsc["max_item"]){
 			$out .= "<font color=\"red\">". _("Maximum number reached") ."!</font><br>";
 		}else{
-			$out .= "<form name=\"".$dsc["action"]."_new_item_frm\" action=\"?\">$fw
+			$out .= "<form method=\"$conf_post_or_get\" name=\"".$dsc["action"]."_new_item_frm\" action=\"?\">$fw
 				<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new_item\">".dtcFormTableAttrs();
 			for($i=0;$i<$nbr_fld;$i++){
 				if( isset($dsc["cols"][ $keys[$i] ]["help"])){
@@ -1712,7 +1747,7 @@ function dtcListItemsEdit($dsc){
 		$n = mysql_num_rows($r);
 		if($n == 1){
 			$a = mysql_fetch_array($r);
-			$out .= "<form name=\"".$dsc["action"]."_save_item_frm\" action=\"?\">$fw";
+			$out .= "<form method=\"$conf_post_or_get\" name=\"".$dsc["action"]."_save_item_frm\" action=\"?\">$fw";
 			$out .= "<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_save_item\">";
 			$out .= "<input type=\"hidden\" name=\"subaction\" value=\"".$dsc["action"]."_edit_item\">";
 			$out .= "<input type=\"hidden\" name=\"item\" value=\"".$a[ $dsc["id_fld"] ]."\">";
@@ -1841,7 +1876,7 @@ function dtcListItemsEdit($dsc){
 					break;
 				}
 			}
-			$delete_button = "<form action=\"?\">$fw
+			$delete_button = "<form method=\"$conf_post_or_get\" action=\"?\">$fw
 			<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_delete_item"."\">
 			<input type=\"hidden\" name=\"$id_fldname\" value=\"$id_fld_value\">
 			".dtcDeleteButton()."</form>";
