@@ -5,7 +5,7 @@ function checkLoginPassSubmitToSQL(){
 	global $adm_pass;
 	global $pro_mysql_admin_table;
 
-	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND adm_pass='$adm_pass';";
+	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR adm_pass=SHA1('$adm_pass'));";
 	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	if($num_rows != 1)      die("User or password is incorrect !");
@@ -16,7 +16,7 @@ function checkLoginPassSubmitToSQL(){
 /////////////////////
 // https://dtc.gplhost.com/dtc/?adm_login=dianflon&adm_pass=dec0lease&addrlink=myaccount&action=refund&refund_amount=12
 if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "refund"){
-	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND adm_pass='$adm_pass';";
+	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR adm_pass=SHA1('$adm_pass'));";
 	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	if($num_rows != 1)      die("User or password is incorrect !");
@@ -81,4 +81,15 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "registry_renew_domain")
 	}
 }
 
+if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_one_domain" && isset($_REQUEST["confirm_delete"]) && $_REQUEST["confirm_delete"] == "yes"){
+	if(!isHostnameOrIP($_REQUEST["to_delete_domain_name"])){
+		die("Not a domain name");
+	}
+	checkLoginPassAndDomain($adm_login,$adm_pass,$_REQUEST["to_delete_domain_name"]);
+	deleteUserDomain($adm_login,$adm_pass,$_REQUEST["to_delete_domain_name"],true);
+	$adm_query = "UPDATE $pro_mysql_cronjob_table SET qmail_newu='yes',restart_qmail='yes',reload_named='yes',restart_apache='yes',gen_vhosts='yes',gen_named='yes',gen_qmail='yes',gen_webalizer='yes',gen_backup='yes',gen_ssh='yes' WHERE 1;";
+	mysql_query($adm_query);
+	triggerDomainListUpdate();
+}
+
 ?>
