@@ -29,6 +29,7 @@ if($panel_type !="email"){
 	require("$dtcshared_path/inc/forms/vps_installation.php");
 	require("$dtcshared_path/inc/forms/dedicated.php");
 	require("$dtcshared_path/inc/forms/multiple_renew.php");
+	require("$dtcshared_path/inc/forms/customservices.php");
 }
 require("$dtcshared_path/inc/forms/email.php");
 require("$dtcshared_path/inc/forms/aliases.php");
@@ -49,6 +50,7 @@ function drawPasswordChange(){
 	global $addrlink;
 	global $pro_mysql_admin_table;
 	global $conf_enforce_adm_encryption;
+	global $conf_post_or_get;
 
 	$pass_submit_err = "";
 
@@ -76,7 +78,7 @@ function drawPasswordChange(){
 
 	$out = "<h3>". _("Change your password:") ."</h3><br>
 $pass_submit_err
-<form action=\"?\" method=\"post\">
+<form method=\"$conf_post_or_get\" action=\"?\" method=\"post\">
 ".dtcFormTableAttrs()."
 <input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -92,6 +94,8 @@ function drawAdminTools($admin){
 	global $adm_login;
 	global $adm_pass;
 	global $edit_domain;
+	global $edit_domain_idn;
+	global $idn;
 	global $whatdoiedit;
 	global $domain_conf_submenu;
 	
@@ -109,9 +113,13 @@ function drawAdminTools($admin){
 	global $vps_node;
 	global $vps_name;
 	global $dedicated_server_hostname;
+	global $custom_id;
 	global $server_subscreen;
 	global $vps_subcommand;
 
+	global $pro_mysql_custom_product_table;
+	global $pro_mysql_product_table;
+
 	$add_array = explode("/",$addrlink);
         $doms_txt = "";
 
@@ -136,6 +144,13 @@ function drawAdminTools($admin){
 		$nbr_dedicated = 0;
 	}
 
+	if(isset($admin["custom"])){
+		$admin_custom = $admin["custom"];
+		$nbr_custom = sizeof($admin_custom);
+	}else{
+		$nbr_custom = 0;
+	}
+
 	$admin_info = $admin["info"];
 
 	$adm_cur_pass 	= $admin_info["adm_pass"];
@@ -167,11 +182,13 @@ function drawAdminTools($admin){
 		"icon" => "box_wnb_nb_picto-addadomainname.gif",
 		"type" => "link",
 		"link" => "adddomain");
-	$user_ZEmenu[] = array(
-		"text" => _("Multiple renew") ,
-		"icon" => "box_wnb_nb_picto-addadomainname.gif",
-		"type" => "link",
-		"link" => "multiple-renew");
+	if(($nbr_vps + $nbr_dedicated) > 1){
+		$user_ZEmenu[] = array(
+			"text" => _("Multiple renew") ,
+			"icon" => "box_wnb_nb_picto-addadomainname.gif",
+			"type" => "link",
+			"link" => "multiple-renew");
+	}
 	if($conf_use_registrar_api == "yes" && $nbr_domain > 0){
 		$user_ZEmenu[] = array(
 			"text" => _("DNS NIC handles") ,
@@ -235,6 +252,32 @@ function drawAdminTools($admin){
 			"link" => "server:".$admin_dedicated[$i]["server_hostname"]);
 	}
 
+	//Draw all custom products
+	for($i=0;$i<$nbr_custom;$i++){
+		$q = "SELECT * FROM $pro_mysql_custom_product_table WHERE id='".$admin_custom[$i]["id"]."'";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$custprod_name = _("Error 1 while retriving custom product name");
+		}else{
+			$a = mysql_fetch_array($r);
+			$q = "SELECT * FROM $pro_mysql_product_table WHERE id='".$a["product_id"]."'";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			if($n != 1){
+				$custprod_name = _("Error 2 while retriving custom product name");
+			}else{
+				$a = mysql_fetch_array($r);
+				$custprod_name = $a["name"];
+			}
+		}
+		$user_menu[] = array(
+			"text" => $custprod_name,
+			"icon" => "box_wnb_nb_picto-dedicatedservers.gif",
+			"type" => "link",
+			"link" => "custom:".$admin_custom[$i]["id"]);
+	}
+
 	// Generate the admin tools
 	$doms_txt .= "<b>";
 	unset($selected_domain);
@@ -337,16 +380,17 @@ function drawAdminTools($admin){
 //				"link" => "tools");
 //		}
 //udns.us /add
+		$dom_idn = $idn->decode($dom);
 		if($add_array[0] == $dom){
 		  $selected_domain = array(
-			"text" => "$dom",
+			"text" => $dom_idn,
 			"icon" => "box_wnb_nb_picto-servers.gif",
 			"type" => "menu",
 			"link" => "$dom",
 			"sub" => $domain_conf_submenu);
 		}else{
 		  $not_selected_domains[] = array(
-			"text" => "$dom",
+			"text" => $dom_idn,
 			"icon" => "box_wnb_nb_picto-servers.gif",
 			"type" => "menu",
 			"link" => "$dom",
@@ -453,18 +497,21 @@ function drawAdminTools($admin){
 		}else if(substr($addrlink,0,7) == "server:"){
 			$web_editor .= drawAdminTools_Dedicated($admin,$dedicated_server_hostname);
 			$title = _("Dedicated server") .": $dedicated_server_hostname";
+		}else if(substr($addrlink,0,7) == "custom:"){
+			$web_editor .= drawAdminTools_Custom($admin,$custom_id);
+			$title = _("Dedicated server") .": $dedicated_server_hostname";
 		}else if(@$add_array[1] == "mailboxs"){
                         $web_editor .= "<img src=\"gfx/toolstitles/mailboxs.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Mailboxes:") ."</u></b><br></font>";
                         $web_editor .= drawAdminTools_Emails($eddomain);
-                  	$title = _("Mailboxes of ") .$edit_domain;
+                  	$title = _("Mailboxes of ") .$edit_domain_idn;
 		}else if(@$add_array[1] == "mailaliases"){
                         $web_editor .= "<img src=\"gfx/toolstitles/mailaliasgroup.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Mail Groups:") ."</u></b><br></font>";
                         $web_editor .= drawAdminTools_Aliases($eddomain);
-                  	$title = _("Mail groups of ").$edit_domain;
+                  	$title = _("Mail groups of ").$edit_domain_idn;
 		}else if(@$add_array[1] == "mailing-lists"){
                         $web_editor .= "<img src=\"gfx/toolstitles/mailing-lists.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Mailing lists:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_MailingLists($eddomain);
-			$title = _("Edit mailing lists of domain:") .$edit_domain;
+			$title = _("Edit mailing lists of domain:") .$edit_domain_idn;
 		//udns.us add
 		}else if(@$add_array[1] == "tools"){
 			$web_editor .= "<img src=\"gfx/toolstitles/tools.png\" align=\"left\"><font size=\"+2\"><b><u>Tools:</u></b><br></font>";
@@ -475,7 +522,7 @@ function drawAdminTools($admin){
 		}else if(@$add_array[1] == "dns"){
                         $web_editor .= "<img src=\"gfx/toolstitles/nameservers.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Name servers:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_DomainDNS($admin,$eddomain);
-			$title = _("DNS config of:") ." ".$edit_domain;
+			$title = _("DNS config of:") ." ".$edit_domain_idn;
 		}else if(@$add_array[1] == "invoices"){
 			$web_editor .= "<img src=\"gfx/toolstitles/stats.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Invoices") .":</u></b><br></font>";
 			$web_editor .= drawAdminTools_Invoices($admin);
@@ -488,32 +535,32 @@ function drawAdminTools($admin){
 			}else{
 				$web_editor .= "<img src=\"gfx/toolstitles/stats.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Statistics:") ."</u></b><br></font>";
 				$web_editor .= drawAdminTools_DomainStats($admin,$eddomain);
-				$title = _("Statistics of domain:")." ".$edit_domain;
+				$title = _("Statistics of domain:")." ".$edit_domain_idn;
 			}
 		}else if(@$add_array[1] == "whois"){
                         $web_editor .= "<img src=\"gfx/toolstitles/nickhandles.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Whois:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_Whois($admin,$eddomain);
-			$title = _("Whois of:") ." ".$edit_domain;
+			$title = _("Whois of:") ." ".$edit_domain_idn;
 		}else if(@$add_array[1] == "subdomains"){
                         $web_editor .= "<img src=\"gfx/toolstitles/subdomains.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Subdomains:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_Subdomain($admin,$eddomain);
-			$title = _("Subdomains of ") .$edit_domain;
+			$title = _("Subdomains of ") .$edit_domain_idn;
 		}else if(@$add_array[1] == "cronjobs"){
 			$web_editor .= "<img src=\"gfx/toolstitles/subdomains.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Cron jobs:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_User_CronJob($admin,$eddomain);
-			$title = _("Cron jobs of ") .$edit_domain;
+			$title = _("Cron jobs of ") .$edit_domain_idn;
 		}else if(@$add_array[1] == "ftp-accounts"){
                         $web_editor .= "<img src=\"gfx/toolstitles/ftp-accounts.png\" align=\"left\"><font size=\"+2\"><b><u>". _("FTP accounts") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_Ftp($eddomain,$adm_path);
-			$title = _("FTP accounts of ") .$edit_domain;
+			$title = _("FTP accounts of ") .$edit_domain_idn;
 		}else if(@$add_array[1] == "ssh-accounts"){
                         $web_editor .= "<img src=\"gfx/toolstitles/ssh-accounts.png\" align=\"left\"><font size=\"+2\"><b><u>". _("SSH accounts:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_SSH($eddomain,$adm_path);
-			$title = _("SSH accounts of ") .$edit_domain;
+			$title = _("SSH accounts of ") .$edit_domain_idn;
 		}else if(@$add_array[1] == "package-installer"){
                         $web_editor .= "<img src=\"gfx/toolstitles/package-installer.png\" align=\"left\"><font size=\"+2\"><b><u>"._("Package installer:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_PackageInstaller($eddomain,$adm_path);			
-			$title = _("Package") .": ".$edit_domain;
+			$title = _("Package") .": ".$edit_domain_idn;
 		}else if(@$add_array[1] == "nickhandles"){
                         $web_editor .= "<img src=\"gfx/toolstitles/nickhandles.png\" align=\"left\"><font size=\"+2\"><b><u>". _("DNS NIC handles") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_NickHandles($admin);
@@ -665,9 +712,9 @@ effect in realtime.<br><br>
 </a></pre>";
 			$title = _("Online DTC help");
 		}else{
-                        $web_editor .= "<img src=\"gfx/toolstitles/domains.png\" align=\"left\"><font size=\"+2\"><b><u>$addrlink:</u></b><br></font>";
+                        $web_editor .= "<img src=\"gfx/toolstitles/domains.png\" align=\"left\"><font size=\"+2\"><b><u>$edit_domain_idn:</u></b><br></font>";
 			$web_editor .= drawAdminTools_DomainInfo($admin,$eddomain);
-			$title = _("General Information ") .$edit_domain;
+			$title = _("General Information ") .$edit_domain_idn;
 		}
 		$edition = skin($conf_skin,$web_editor,$title);
 	}else{
