@@ -435,6 +435,7 @@ function fetchAdminData($adm_login,$adm_input_pass){
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_vps_server_table;
 	global $pro_mysql_dedicated_table;
+	global $pro_mysql_custom_product_table;
 	global $panel_type;
 
 	global $conf_session_expir_minute;
@@ -442,7 +443,8 @@ function fetchAdminData($adm_login,$adm_input_pass){
 	global $adm_realpass;
 	global $adm_pass;
 	global $adm_random_pass;
-
+	global $idn;
+	
 	// This one is used by the root GUI so that you can browse your user
 	// account at the same time as him without destroying his session.
 	global $DONOT_USE_ROTATING_PASS;
@@ -522,6 +524,20 @@ function fetchAdminData($adm_login,$adm_input_pass){
 		$user_dedicated[] = mysql_fetch_array($r);
 	}
 
+	// Get all custom products of the user
+	$q = "SELECT * FROM $pro_mysql_custom_product_table WHERE owner='$adm_login' ORDER BY id;";
+	$r = mysql_query ($q);
+	if (!$r){
+		$ret["err"] = 3;
+		$ret["mesg"]="Cannot execute query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error();
+		return $ret;
+	}
+	$n = mysql_num_rows($r);
+	$user_custom = array();
+	for($i=0;$i<$n;$i++){
+		$user_custom[] = mysql_fetch_array($r);
+	}
+
 	// Get all domains of the user
 	$query = "SELECT * FROM $pro_mysql_domain_table WHERE owner='$adm_login' ORDER BY name;";
 	$result = mysql_query ($query);
@@ -532,8 +548,8 @@ function fetchAdminData($adm_login,$adm_input_pass){
 		return $ret;
 	}
 	$num_rows = mysql_num_rows($result);
+	// re-order by name, using idn
 	for($i=0;$i<$num_rows;$i++){
-		//echo "$i<br>";
 		$row = mysql_fetch_array($result);
 		if (!$row)
 		{
@@ -541,6 +557,18 @@ function fetchAdminData($adm_login,$adm_input_pass){
 			$ret["mesg"] = "Cannot fetch domain";
 			return $ret;
 		}
+		$domains[] = $row;
+		$b[$i] = $idn->decode($row["name"]);	
+	}
+	if (is_array($b)) {
+		asort($b, SORT_LOCALE_STRING);
+		foreach($b as $key=>$val) {
+			$domains_idnsorted[] = $domains[$key];
+		}
+	}
+	for($i=0;$i<$num_rows;$i++){
+		//echo "$i<br>";
+		$row = $domains_idnsorted[$i]; //mysql_fetch_array($result);
 		unset($domain);
 		$domain["name"] = $row["name"];
 		$domain["safe_mode"] = $row["safe_mode"];
@@ -870,6 +898,9 @@ function fetchAdminData($adm_login,$adm_input_pass){
 	if(isset($user_dedicated)){
 		$ret["dedicated"] = $user_dedicated;
 	}
+	if(isset($user_custom)){
+		$ret["custom"] = $user_custom;
+	}
 	return $ret;
 }
 
@@ -996,6 +1027,9 @@ function fetchAdmin($adm_login, $adm_pass){
 	if(isset($data["dedicated"])){
 		$ret["dedicated"] = $data["dedicated"];
 	}
+	if(isset($data["custom"])){
+		$ret["custom"] = $data["custom"];
+	}
 	return $ret;
 }
 
