@@ -14,6 +14,7 @@ function drawDataBase($database){
 	global $conf_user_mysql_host;
 	global $conf_user_mysql_root_login;
 	global $conf_user_mysql_root_pass;
+	global $conf_post_or_get;
 
 	global $conf_demo_version;
 	global $conf_user_mysql_prepend_admin_name;
@@ -26,11 +27,13 @@ function drawDataBase($database){
 	if($n != 1)	die("Cannot find user !");
 	$admin_param = mysql_fetch_array($r);
 
+	$out = "";
 	if($conf_user_mysql_type=="distant"){
 		$newid = mysql_connect($conf_user_mysql_host,$conf_user_mysql_root_login,$conf_user_mysql_root_pass)or die("Cannot connect to user SQL host");
+	}else {
+	    $out = "<br />" . _("Please use 127.0.0.1 instead of localhost to connect to the database in your scripts.") . "<br />";
 	}
-
-	$out = "<br><h3>". _("Your users") ."</h3>";
+	$out .= "<br /><h3>". _("Your users") ."</h3>";
 	if($conf_user_mysql_prepend_admin_name == "yes"){
 		$out .= "<i>" . _("Your username will be prepended to the database username.") . "</i><br>";
 	}
@@ -45,13 +48,13 @@ function drawDataBase($database){
 	$dblist_user = "";
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		$out .= "<tr><td><form action=\"?\">$hidden
+		$out .= "<tr><td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 		<input type=\"hidden\" name=\"action\" value=\"modify_dbuser_pass\">
 		<input type=\"hidden\" name=\"dbuser\" value=\"".$a["User"]."\">
 		".$a["User"]."</td>
 		<td><input type=\"text\" name=\"db_pass\" value=\"\"></td>
 		<td><input type=\"submit\" value=\"". _("Save") ."\"></form></td>
-		<td><form action=\"?\">$hidden
+		<td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 		<input type=\"hidden\" name=\"action\" value=\"del_dbuser\">
 		<input type=\"hidden\" name=\"dbuser\" value=\"".$a["User"]."\">
 		<input type=\"submit\" value=\"". _("Delete") ."\"></form></td></tr>";
@@ -62,7 +65,7 @@ function drawDataBase($database){
 		}
 		$dblist_user[] = $a["User"];
 	}
-	$out .= "<tr><td><form action=\"?\">$hidden
+	$out .= "<tr><td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 	<input type=\"hidden\" name=\"action\" value=\"add_dbuser\">
 	<input type=\"text\" name=\"dbuser\" value=\"\"></td>
 	<td><input type=\"text\" name=\"db_pass\" value=\"\"></td>
@@ -94,12 +97,12 @@ function drawDataBase($database){
 				}
 			}
 			$dblist .= "<tr><td>".$row["Db"]."</td>";
-			$dblist .= "<td><form action=\"?\">$hidden
+			$dblist .= "<td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 			<input type=\"hidden\" name=\"action\" value=\"change_db_owner\">
 			<input type=\"hidden\" name=\"dbname\" value=\"".$row["Db"]."\">
 			<select name=\"dbuser\">$dblist_user_popup</select></td>";
 			$dblist .= "<td><input type=\"submit\" value=\"". _("Save") ."\"></form></td>
-			<td><form action=\"?\">$hidden
+			<td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 			<input type=\"hidden\" name=\"action\" value=\"delete_user_db\">
 			<input type=\"hidden\" name=\"dbname\" value=\"".$row["Db"]."\">
 			<input type=\"submit\" value=\"". _("Delete") ."\"></form></td></tr>";
@@ -111,7 +114,7 @@ function drawDataBase($database){
 				$dblist_user_popup .= "<option value=\"".$dblist_user[$j]."\">".$dblist_user[$j]."</option>";
 			}
 
-			$dblist .= "<tr><td><form action=\"?\">$hidden
+			$dblist .= "<tr><td><form method=\"$conf_post_or_get\" action=\"?\">$hidden
 		<input type=\"hidden\" name=\"action\" value=\"add_dbuser_db\">
 		<input type=\"text\" name=\"newdb_name\"></td>
 				<td><select name=\"dbuser\">$dblist_user_popup</select></td>
