@@ -10,6 +10,9 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 	global $pro_mysql_whois_table;
 	global $renew_return;
 	global $secpayconf_currency_letters;
+	global $conf_post_or_get;
+	global $idn;
+	
 	$out = "";
 
 	$webname = $eddomain["name"];
@@ -48,7 +51,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 						$out .= dtcFormLineDraw( "", "<font color=\"red\">"._("Insufficient balance for the transaction, please go to \"My account\" and add money.")."</font>",0);
 						$out .= "</table>";
 					}else{
-						$out .= dtcFormLineDraw( "", "<form action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+						$out .= dtcFormLineDraw( "", "<form method=\"$conf_post_or_get\" action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"edit_domain\" value=\"".$webname."\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -70,7 +73,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 				}else{
 					$txt = $authcode["response_text"];
 				}
-	                        $frm = "<form action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+	                        $frm = "<form method=\"$conf_post_or_get\" action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"edit_domain\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -114,7 +117,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 					$a["protection"] = $sel;
 				}
 			}
-                        $frm = "<form action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+                        $frm = "<form method=\"$conf_post_or_get\" action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"edit_domain\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -199,7 +202,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 		$radio_yes = "";
 	}
 
-	$out .= "<form action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+	$out .= "<form method=\"$conf_post_or_get\" action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"edit_domain\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -209,7 +212,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 
 	$out .= "<h3>". _("Domain parking:") ."</h3>";
 	$out .= _("This domain will be an alias of the following domain (domain parking):");
-	$out .= "<form action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+	$out .= "<form method=\"$conf_post_or_get\" action=\"?\"><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"edit_domain\" value=\"".$_REQUEST["addrlink"]."\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -227,7 +230,7 @@ function drawAdminTools_DomainInfo($admin,$eddomain){
 		}else{
 			$checked = "";
 		}
-		$out .= "<option value=\"".$a["name"]."\"$checked>".$a["name"]."</option>";
+		$out .= "<option value=\"".$a["name"]."\"$checked>".$idn->decode($a["name"])."</option>";
 	}
 
 	$out .= "</select><br>";
