@@ -15,7 +15,9 @@ function drawEditAdmin($admin){
 	global $adm_pass;
 	global $rub;
 	global $conf_hide_password;
-
+	global $conf_post_or_get;
+	global $idn;
+	
 	$info = $admin["info"];
 	if(isset($admin["data"])){
 		$data = $admin["data"];
@@ -165,7 +167,7 @@ function drawEditAdmin($admin){
 
 	// Generate the user configuration form
 	$user_data = "
-<form name=\"admattrbfrm\" action=\"?\" methode=\"post\">
+<form method=\"$conf_post_or_get\" name=\"admattrbfrm\" action=\"?\" methode=\"post\">
 <input type=\"hidden\" name=\"rub\" value=\"$rub\">
 <input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -227,19 +229,20 @@ function drawEditAdmin($admin){
 		$nbr_domain = sizeof($data);
 		for($i=0;$i<$nbr_domain;$i++){
 			$dom = $data[$i]["name"];
+			$dom_idn = $idn->decode($dom);
 			if($i != 0){
 				$domain_conf .= " - ";
 			}
 			$url = "?adm_login=$adm_login&adm_pass=$adm_pass&deluserdomain=$dom&rub=$rub";
 			$js_url = dtcJavascriptConfirmLink( _("Are you sure you want to delete this domain name? This will DELETE all hosted files for this domain.") ,$url);
-			$domain_conf .= "<a href=\"$js_url\">$dom</a>";
+			$domain_conf .= "<a href=\"$js_url\">$dom_idn</a>";
 		}
 		$domain_conf .= "</b><br><br>";
 	}
 	// Creation of domains :
 	$domain_conf .= "<h3>". _("Add a domain for this user:") ."</h3>";
 
-	$domain_conf .= "<form action=\"?\"><table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">
+	$domain_conf .= "<form method=\"$conf_post_or_get\" action=\"?\"><table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">
 <tr><td><input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 	<input type=\"hidden\" name=\"rub\" value=\"$rub\">
 	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -252,7 +255,7 @@ function drawEditAdmin($admin){
 	</form>";
 
 	$domain_conf .= "<h3>". _("Import a domain file for this user:") ."<h3></b>
-	<form action=\"?\" enctype=\"multipart/form-data\" method=\"post\">
+	<form method=\"$conf_post_or_get\" action=\"?\" enctype=\"multipart/form-data\" method=\"post\">
 	<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">
 	<tr><td><input type=\"hidden\" name=\"rub\" value=\"$rub\">
 	<input type=\"hidden\" name=\"action\" value=\"import_domain\">
@@ -304,7 +307,7 @@ function drawEditAdmin($admin){
 	}
 	if($n > 0 && $num_prods_vps > 0){
 		$domain_conf .= "<h3>". _("Add a VPS for this admin:") ."</h3>
-		<form action=\"?\">
+		<form method=\"$conf_post_or_get\" action=\"?\">
 		<input type=\"hidden\" name=\"rub\" value=\"$rub\">
 		<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 		<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -351,7 +354,7 @@ function drawEditAdmin($admin){
 		$server_prods .= "<option value=\"".$a["id"]."\">".$a["name"]."</option>";
 	}
 	$domain_conf .= "<br><br><h3>". _("Add a dedicated server for this admin:") ."</h3>
-	<form action=\"?\">
+	<form method=\"$conf_post_or_get\" action=\"?\">
 	<input type=\"hidden\" name=\"rub\" value=\"$rub\">
 	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -389,15 +392,20 @@ function drawDomainConfig($admin){
 	global $pro_mysql_vps_table;
 	global $pro_mysql_dedicated_table;
 	global $pro_mysql_subdomain_table;
+	global $pro_mysql_custom_product_table;
+	global $pro_mysql_custom_heb_types_fld_table;
+	global $pro_mysql_custom_heb_types_table;
 
 	global $conf_site_addrs;
 	global $conf_use_shared_ssl;
+	global $conf_post_or_get;
 
 	$site_addrs = explode("|",$conf_site_addrs);
 
 	global $adm_login;
 	global $adm_pass;
-
+	global $idn;
+	
 	$ret = "";
 
 	if(isset($admin["data"])){
@@ -422,6 +430,7 @@ function drawDomainConfig($admin){
 			"skip_deletion" => "yes",
 			"skip_creation" => "yes",
 			"where_condition" => "owner='$adm_login'",
+			"order_by" => "name",
 			"cols" => array(
 				"name" => array(
 					"type" => "id",
@@ -484,7 +493,7 @@ function drawDomainConfig($admin){
 			);
 		$ret .= dtcDatagrid($dsc);
 		if( isset($_REQUEST["edithost"]) && isHostname($_REQUEST["edithost"]) ){
-			$ret .= "<h3>". _("Custom Apache directives for") ." ".$_REQUEST["edithost"]."</h3>";
+			$ret .= "<h3>". _("Custom Apache directives for") ." ".$idn->decode($_REQUEST["edithost"])."</h3>";
 			$q = "SELECT subdomain_name FROM $pro_mysql_subdomain_table WHERE domain_name='".$_REQUEST["edithost"]."';";
 			$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
@@ -667,6 +676,11 @@ function drawDomainConfig($admin){
 					"size" => "5",
 					"help" => _("Bandwidth per month in MBytes."),
 					"legend" => _("Bandwidth") ),
+				"locked" => array(
+					"type" => "checkbox",
+					"values" => array("yes","no"),
+					"display_replace" => array(_("Yes"),_("No")),
+					"legend" => _("Locked") ),
 				"product_id" => array(
 					"type" => "popup",
 					"legend" => _("Product ID") ,
@@ -749,6 +763,69 @@ function drawDomainConfig($admin){
 				));
 		$ret .= dtcDatagrid($dsc);
 	}
+
+	// Custom Product configuration
+	if(isset($admin["custom"])){
+		$servers = $admin["custom"];
+		$nbr_server = sizeof($servers);
+	}else{
+		$nbr_server = 0;
+	}
+	if($nbr_server > 0){
+		$q = "SELECT id,name FROM $pro_mysql_product_table WHERE heb_type='custom' AND renew_prod_id='0';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		$prod_name = array();
+		$prod_id = array();
+		for($i=0;$i<$n;$i++){
+			$a = mysql_fetch_array($r);
+			$prod_name[] = $a["name"];
+			$prod_id[] = $a["id"];
+		}
+
+		$dsc = array(
+			"table_name" => $pro_mysql_custom_product_table,
+			"title" => "",
+			"action" => _("Configuration of the Custom product") ,
+			"forward" => array("rub","adm_login","adm_pass"),
+			"skip_deletion" => "yes",
+			"skip_creation" => "yes",
+			"where_condition" => "owner='$adm_login'",
+			"cols" => array(
+				"id" => array(
+					"type" => "id",
+					"display" => "no",
+					"legend" => "id"),
+				"domain" => array(
+					"type" => "text",
+					"legend" => _("Domain") ),
+				"start_date" => array(
+					"type" => "text",
+					"help" => _("Format: YYYY-MM-DD."),
+					"size" => "10",
+					"legend" => _("Registration") ),
+				"expire_date" => array(
+					"type" => "text",
+					"help" => _("Format: YYYY-MM-DD."),
+					"size" => "10",
+					"legend" => _("Expiration") ),
+				"custom_heb_type_fld" => array(
+					"type" => "text",
+					"legend" => _("Custom fields and values")
+				),
+				"country_code" => array(
+					"type" => "popup",
+					"legend" => _("Country") ,
+					"values" => array_keys($cc_code_array),
+					"display_replace" => array_values($cc_code_array)),
+				"product_id" => array(
+					"type" => "popup",
+					"legend" => _("Product") ,
+					"values" => $prod_id,
+					"display_replace" => $prod_name)
+				));
+		$ret .= dtcDatagrid($dsc);
+	}
 	return $ret;
 }
 
