@@ -22,6 +22,7 @@ function subdomainCreateDirsCallBack($id){
 	global $conf_demo_version;
 	global $conf_generated_file_path;
 	global $conf_unix_type;
+	global $pro_mysql_subdomain_table;
 
 	setZoneToGenerate($id);
 	$adm_path = getAdminPath($adm_login);
@@ -29,6 +30,24 @@ function subdomainCreateDirsCallBack($id){
 	$domain = $doms[0];
 	$newsubdomain_dirpath = $adm_path."/".$domain."/subdomains/".$_REQUEST["subdomain_name"];
 
+	$q = "SELECT * FROM $pro_mysql_subdomain_table WHERE id='$id';";
+	$r = mysql_query($q)or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	$shared_hosting_security = "sbox_copy";
+	if($n != 1){
+		echo "<font color=\"red\">". _("Could not found subdomain in table for folder deletion") ."</font>";
+	}else{
+		$a = mysql_fetch_array($r);
+		if($a["shared_hosting_security"] == "mod_php" && $a["shared_hosting_security"] == "mod_php"){
+			$shared_hosting_security = "mod_php";
+		}
+	}
+
+	if ($conf_unix_type == "bsd") {
+		$CP = "cp -flpRv";
+	}else{
+		$CP = "cp -fulpRv";
+	}
 	if($conf_demo_version == "no"){
 		if(!file_exists("$newsubdomain_dirpath"))
 			mkdir("$newsubdomain_dirpath", 0750);
@@ -38,13 +57,21 @@ function subdomainCreateDirsCallBack($id){
 			mkdir("$newsubdomain_dirpath/cgi-bin", 0750);
 		if(!file_exists("$newsubdomain_dirpath/logs"))
 			mkdir("$newsubdomain_dirpath/logs", 0750);
-		if ($conf_unix_type == "bsd") {
-			exec("cp -flpRv $conf_chroot_path/* $newsubdomain_dirpath");
-		}else{
-			exec("cp -fulpRv $conf_chroot_path/* $newsubdomain_dirpath");
+		switch($shared_hosting_security){
+		case "mod_php":
+			exec("$CP $conf_chroot_path/* $newsubdomain_dirpath");
+			system ("if [ ! -e $newsubdomain_dirpath/html/index.* ]; then cp -rf $conf_generated_file_path/template/* $newsubdomain_dirpath/html; fi");
+			break;
+		case "sbox_copy":
+			exec("$CP /var/lib/dtc/sbox_copy/* $newsubdomain_dirpath");
+			system ("if [ ! -e $newsubdomain_dirpath/html/index.* ]; then cp -rf $conf_generated_file_path/template/* $newsubdomain_dirpath/html; fi");
+			break;
+		// Todo: implement sbox_aufs
+		default:
+			echo "<font color=\"red\">". _("sbox_aufs not implemented yet!") ."</font>";
+			break;
 		}
-		system ("if [ ! -e $newsubdomain_dirpath/html/index.* ]; then cp -rf $conf_generated_file_path/template/* $newsubdomain_dirpath/html; fi");
-		updateUsingCron("gen_vhosts='yes',restart_apache='yes',gen_named='yes',reload_named ='yes',gen_backup='yes'");
+		updateUsingCron("gen_vhosts='yes',restart_apache='yes',gen_named='yes',reload_named ='yes',gen_backup='yes',gen_webalizer='yes'");
 	}
 	return;
 }
@@ -192,6 +219,11 @@ function drawAdminTools_Subdomain($admin,$domain){
 				"check" => "list_of_ip",
 				"can_be_empty" => "yes",
 				"legend" => _("Supplementary IP list for round robin: ") ),
+			"shared_hosting_varwww_docroot" => array(
+				"type" => "radio",
+				"legend" => _("Path of the DocumentRoot in the SBOX chroot: "),
+				"values" => array("no","yes"),
+				"display_replace" => array("/html","/var/www") ),
 			"ttl" => array(
 				"type" => "text",
 				"check" => "number",
@@ -253,6 +285,12 @@ function drawAdminTools_Subdomain($admin,$domain){
 				"display_replace" => array(_("Yes"),_("No")),
 				"legend" => _("Sbox cgi-bin protection: ") );
 	}
+	if($admin["info"]["shared_hosting_security"] == "mod_php"){
+		$dsc["cols"]["shared_hosting_security"] = array(
+				"type" => "radio",
+				"legend" => _("Subdomain security model: "),
+				"values" => array("mod_php","sbox_copy","sbox_aufs") );
+	}
 
 	// Get all SSL IPs asigned to this customer
 	$q = "SELECT * FROM $pro_mysql_ssl_ips_table WHERE adm_login='$adm_login' AND available='no';";
@@ -287,7 +325,7 @@ function drawAdminTools_Subdomain($admin,$domain){
 		$dsc["cols"]["ssl_ip"] = array(
 			"type" => "popup",
 			"values" => $ssl_ips,
-			"legend" => _("Use an SSL vhost using this IP: ")
+			"legend" => _("SSL vhost listens on this IP: ")
 			);
 	}
 
