@@ -20,12 +20,26 @@ function checkDedicatedAdmin($adm_login,$adm_pass,$dedicated_server_hostname){
 	}
 }
 
+function checkCustomAdmin($adm_login,$adm_pass,$custom_service_id){
+	global $pro_mysql_custom_product_table;
+	checkLoginPass($adm_login,$adm_pass);
+	$q = "SELECT * FROM $pro_mysql_custom_product_table WHERE owner='$adm_login' AND id='".mysql_real_escape_string($custom_service_id)."';";
+	$r = mysql_query($q) or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n == 1){
+		return true;
+	}else{
+		return false;
+	}
+}
+
 function validateRenewal($renew_id){
 	global $pro_mysql_pending_renewal_table;
 	global $pro_mysql_product_table;
 	global $pro_mysql_vps_table;
 	global $pro_mysql_admin_table;
 	global $pro_mysql_dedicated_table;
+	global $pro_mysql_custom_product_table;
 	global $pro_mysql_completedorders_table;
 	global $pro_mysql_client_table;
 	global $pro_mysql_ssl_ips_table;
@@ -212,6 +226,27 @@ A renewal have been paid! Here is the details of the renewal:
 
 login: ";
 		break;
+	case "custom":
+		$q = "SELECT * FROM $pro_mysql_custom_product_table WHERE id='".$renew_entry["renew_id"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$submit_err = "Could not find custom service id in table line ".__LINE__." file ".__FILE__;
+			$commit_flag = "no";
+			return false;
+		}
+		$dedicated_entry = mysql_fetch_array($r);
+		$old_expire = $dedicated_entry["expire_date"];
+		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
+		$q = "UPDATE $pro_mysql_custom_product_table SET expire_date='$date_expire' WHERE id='".$renew_entry["renew_id"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A renewal have been paid! Here is the details of the renewal:
+
+login: ";
+		executeCustomActions($product["id"], 'renew', $renew_entry["renew_id"]);
+		break;
 	case "ssl_renew":
 		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
@@ -581,6 +616,7 @@ last_used_lang   ,path            ,id_client,bandwidth_per_month_mb,quota,nbrdb,
 		// Read the (customizable) registration message to send
 		$txt_welcome_message = readCustomizedMessage("registration_msg/custom_".$product["custom_heb_type"]."_open",$waiting_login);
 		addCustomProductToUser($waiting_login,$new_admin["domain_name"],$product["id"]);
+		executeCustomActions($product["id"], 'new', null, $new_admin);
 		break;
 	default:
 		break;
