@@ -8,6 +8,15 @@ $send_email_header = "Content-Type: text/plain; charset=\"UTF-8\"\n";
 //$send_email_header .= "Content-Transfer-Encoding: 8bit\n";
 $send_email_header .= "Content-Transfer-Encoding: quoted-printable\n";
 
+$version_ar = explode(".",phpversion());
+$php_major_vers = $version_ar[0];
+$php_minor_vers = $version_ar[1];
+if($php_major_vers > 5 || ($php_major_vers == 5 && $php_minor_vers >= 4)){
+        $php_vers_bigger_than_53 = 1;
+}else{
+        $php_vers_bigger_than_53 = 0;
+}
+
 if(isset($_REQUEST["rub"])){
 	if(!preg_match("/^([a-z0-9]+)([.a-z_0-9-]*)([a-z0-9]+)\$/",$_REQUEST["rub"]) && $_REQUEST["rub"] != ""){
 		die("Rub parameter not correct: XSS attempt?");
@@ -79,6 +88,9 @@ if(isset($addrlink) && $addrlink != ""){
 				$vps_name = $vps_exploded[2];
 			}
 			break;
+		case "custom":
+			$custom_id = $vps_exploded[1];
+			break;
 		default:
 			die("No command recognized and a : in \$addrlink line ".__LINE__." file ".__FILE__);
 		}
@@ -99,6 +111,12 @@ if($panel_type != "email" && isset($edit_domain) && !preg_match("/^([a-z0-9]+)([
 	die("The domain provided does not look like a correct domain name...");
 }
 
+require("$dtcshared_path/inc/idna_convert.class.php");
+$idn = new idna_convert(array('idn_version' => 2008));
+if (isset($edit_domain)) {
+	$edit_domain_idn = $idn->decode($edit_domain);	
+}
+
 //don't save things into the session for cronjobs
 if($panel_type!="cronjob"){
 	// Save menu style preference in session
