@@ -32,11 +32,13 @@ $txt_langname = array(
 	"pt_BR" => "UTF-8",
 	"es" => "UTF-8",
 	"fi" => "UTF-8",
-	"lv" => "UTF-8");
+	"lv" => "UTF-8",
+	"cs" => "UTF-8");
 
 //check to see if we are running in the shell or web
 if($panel_type!="cronjob"){
-	session_register("lang");
+	@session_start();
+	if(isset($lang)) $_SESSION["lang"]=$lang;
 	// If something like phpbb that has $lang on the same domain, this should
 	// avoid problems. This is a lack in php (IMHO)
 	if(isset($_SESSION["lang"]) && !is_string($_SESSION["lang"])){
@@ -49,15 +51,15 @@ if($panel_type!="cronjob"){
 		// This is the case of xx_YY
 		if( strlen($_REQUEST["change_language"]) == 5){
 			$exploded_lang = explode("_",$_REQUEST["change_language"]);
-			if( !ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$exploded_lang[0]) ){
+			if( !preg_match("/^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$/",$exploded_lang[0]) ){
 				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
 			}
-			if( !ereg("^([A-Z0-9]+)([.A-Z0-9-]*)([A-Z0-9]+)\$",$exploded_lang[1]) ){
+			if( !preg_match("/^([A-Z0-9]+)([.A-Z0-9-]*)([A-Z0-9]+)\$/",$exploded_lang[1]) ){
 				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
 			}
 		// This is the case of xx only and no _YY
 		}else if( strlen($_REQUEST["change_language"]) == 2){
-			if(!ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$_REQUEST["change_language"])){
+			if(!preg_match("/^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$/",$_REQUEST["change_language"])){
 				die("Lang parameter not correct line ".__LINE__." file ".__FILE__);
 			}
 		}else{
@@ -114,6 +116,9 @@ if($panel_type!="cronjob"){
 		if($_REQUEST["change_language"] == "lv"){
 		  $lang = "lv";
 		}
+		if($_REQUEST["change_language"] == "cs"){
+		  $lang = "cs";
+		}
 	}
 	if(isset($lang)){
 	  $_SESSION["lang"] = $lang;
@@ -219,6 +224,10 @@ case "lv_LV":
 case "lv":
 	$gettext_lang = "lv_LV.UTF-8";
 	break;
+case "cs_CZ":
+case "cs":
+	$gettext_lang = "cs_CZ.UTF-8";
+	break;
 default:
 	$gettext_lang = "en_US.UTF-8";
 	break;
